@@ -408,7 +408,7 @@ def version() -> str:
     :return:
     """
     # v = pkg_resources.require("wizzi_utils")[0].version
-    v = '6.6.10'
+    v = '6.6.14'
     return v
 
 
@@ -616,7 +616,7 @@ def main_wrapper(
     return
 
 
-def get_data_str(data_str_raw, chars: (int, str)) -> str:
+def get_data_str(data_str_raw: str, chars: int) -> str:
     """
     Aux function for to_str()
     :param data_str_raw:
@@ -624,10 +624,8 @@ def get_data_str(data_str_raw, chars: (int, str)) -> str:
     :return: data_str
     """
     data_str_raw = data_str_raw.replace('\n', '').replace('  ', '')
-    if chars == 'all':  # all data
+    if chars == -1:  # all data
         chars = len(data_str_raw) + 1
-    elif chars is None:  # no data
-        chars = 0
 
     data_str_rep = ': {}'.format(data_str_raw[:chars])
 
@@ -666,8 +664,8 @@ def is_dict(var: any) -> bool:
 
 def to_str(var: any,
            title: str = 'var',
-           chars: (int, str) = 100,
-           fp: (int, None) = 2,
+           chars: int = 100,
+           fp: int = 2,
            wm: bool = True,
            rec: bool = False
            ) -> str:
@@ -676,97 +674,100 @@ def to_str(var: any,
     :param title: str: the title (usually variable name)
     :param chars: int, None or str:
         chars>0: maximal number of chars
-        chars==None: no chars
-        chars=='all': all chars
+        chars==0: no chars
+        chars==-1: all chars
     :param fp: float_precision: round number if possible(float, list or np array of floats...)
             fp>=0 round
-            fp==None: no rounding
+            fp==-1: no rounding
     :param wm: with_meta: with meta data such as type, len\shape, dtype...
     :param rec: recursive: to keep printing if there are more items inside e.g. np.array(shape=(2,3,4)) -> 3 prints
     :return: informative string of the variable
     see to_str_test()
     """
+    if fp >= 0:
+        int_str_f = '{:,}'
+        float_str_f = '{:,.%xf}' % fp
+    else:
+        int_str_f, float_str_f = None, None
 
     string = title
+    type_s = str(type(var)).replace('<class \'', '').replace('\'>', '')  # clean type name
 
     if is_float(var):
         if wm:
-            type_s = str(type(var)).replace('<class \'', '').replace('\'>', '')  # clean type name
             string += '({})'.format(type_s)
-        if fp is not None and fp >= 0:
-            f_format = '{:,.%xf}' % fp
-        else:
-            f_format = '{:,}'
-        data_str_raw = f_format.format(var)
-        string += get_data_str(data_str_raw, chars)
+        if chars != 0:  # -1 for all, or x>0 for x chars
+            if fp == 0:
+                data_str_raw = int_str_f.format(var)
+            elif fp > 0:
+                data_str_raw = float_str_f.format(var)
+            else:
+                data_str_raw = str(var)
+            string += get_data_str(data_str_raw, chars)
 
     elif is_int(var):
         if wm:
-            type_s = str(type(var)).replace('<class \'', '').replace('\'>', '')  # clean type name
             string += '({})'.format(type_s)
-        data_str_raw = '{:,}'.format(var)
-        string += get_data_str(data_str_raw, chars)
+        if chars != 0:  # -1 for all, or x>0 for x chars
+            data_str_raw = int_str_f.format(var)
+            string += get_data_str(data_str_raw, chars)
 
     elif is_str(var):
         if wm:
-            type_s = str(type(var)).replace('<class \'', '').replace('\'>', '')  # clean type name
             string += '({}'.format(type_s)
             string += ',len={})'.format(var.__len__())
-        string += get_data_str(var, chars)
+        if chars != 0:  # -1 for all, or x>0 for x chars
+            string += get_data_str(var, chars)
 
     elif is_list(var) or is_tuple(var):
         if wm:
-            type_s = str(type(var)).replace('<class \'', '').replace('\'>', '')  # clean type name
             string += '({}'.format(type_s)
             string += ',len={})'.format(var.__len__())
 
-        if fp is not None and fp >= 0:
-            # 1d list\tuple - nice print
-            if all((is_int(item) or is_float(item)) for item in var):
-                if fp > 0 and all(is_int(item) for item in var):
-                    fp = 0
-                f_format = '{:,.%xf}' % fp
-                new_v = [f_format.format(li_item) for li_item in var]
-            else:  # 2d list\tuple - could fail if found strings or types that cant be rounded
-                # new_v = round_list(var, fp)
-                new_v = var  # NO rounding for now to avoid VisibleDeprecationWarnin
-        else:  # fp = None - no rounding
-            new_v = var
+        if chars != 0:  # -1 for all, or x>0 for x chars
+            if fp >= 0:
+                if is_list(var):
+                    new_v = round_list(var, fp=fp)
+                else:
+                    new_v = round_tuple(var, fp=fp)
+            else:
+                new_v = var
+            data_str_raw = str(new_v).replace('\'', '')
 
-        if is_tuple(var):
-            new_v = tuple(new_v)
+            string += get_data_str(data_str_raw, chars)
 
-        data_str_raw = str(new_v).replace('\'', '')
-
-        string += get_data_str(data_str_raw, chars)
         if rec and len(var) > 0:
             inner_str = to_str(var=var[0], title='{}[0]'.format(title), chars=chars, fp=fp, rec=rec)
             string += '\n\t{}'.format(inner_str)
 
     elif is_numpy(var):
         if wm:
-            type_s = str(type(var)).replace('<class \'', '').replace('\'>', '').replace('numpy.', '')
             string += '({}'.format(type_s)
             string += ',s={}'.format(var.shape)
             string += ',dtype={})'.format(var.dtype)
+        if chars != 0:  # -1 for all, or x>0 for x chars
+            if fp >= 0:
+                new_v = round_list(var.tolist(), fp=fp)
+            else:
+                new_v = var.tolist()
+
+            data_str_raw = str(new_v).replace('\'', '')
+            string += get_data_str(data_str_raw, chars)
 
-        if fp is not None and fp >= 0:
-            new_v = np.round(var.tolist(), fp).tolist()
-        else:
-            new_v = var.tolist()
-        data_str_raw = str(new_v).replace('\'', '')
-        string += get_data_str(data_str_raw, chars)
         if rec and var.shape[0] > 0:  # recursive call
             inner_str = to_str(var=var[0], title='{}[0]'.format(title), chars=chars, fp=fp, rec=rec)
             string += '\n\t{}'.format(inner_str)
 
     elif is_dict(var):
         if wm:
-            type_s = str(type(var)).replace('<class \'', '').replace('\'>', '')  # clean type name
             string += '({}'.format(type_s)
             string += ',len={}'.format(var.__len__())
-            string += ',keys={})'.format(list(var.keys()))
-        string += get_data_str(str(var), chars)
+            if len(var.keys()) <= 5:  # only small amount of keys with be printed.
+                string += ',keys={})'.format(list(var.keys()))
+
+        if chars != 0:  # -1 for all, or x>0 for x chars
+            string += get_data_str(str(var), chars)
+
         if rec and len(var) > 0:  # recursive call
             first_k = next(iter(var))
             inner_str = to_str(var=var[first_k], title='{}[{}]'.format(title, first_k), chars=chars, fp=fp, rec=rec)
@@ -776,9 +777,10 @@ def to_str(var: any,
         # all unidentified elements get default print (title(type): data)
         # must have str() to this type
         if wm:
-            type_s = str(type(var)).replace('<class \'', '').replace('\'>', '')  # clean type name
             string += '({})'.format(type_s)
-        string += get_data_str(str(var), chars)
+
+        if chars != 0:  # -1 for all, or x>0 for x chars
+            string += get_data_str(str(var), chars)
     return string
 
 
@@ -1530,15 +1532,24 @@ def round_list(li: (list, tuple), fp: int = 3, warn: bool = False):
     :return: new_li: rounded list
     see round_list_test()
     """
+
     new_li = li
-    if fp >= 0:
-        try:
-            new_np = np.array(li)
-            if np.dtype == np.float64 or np.dtype == np.float32 or np.float:
-                new_li = np.around(new_np, fp).tolist()
-        except TypeError as e:
-            if warn:
-                exception_error(e, real_exception=True)
+    if fp >= 0 and len(li) > 0:
+        if all((is_int(item) or is_float(item)) for item in li):  # 1d list of int and floats
+            if all(is_int(item) for item in li):  # if all ints - no rounding
+                f_format = '{:,}'
+            else:
+                f_format = '{:,.%xf}' % fp
+            new_li = [f_format.format(li_item) for li_item in li]
+        else:  # >1d list or 1d with not just ints and floats
+            try:
+                new_np = np.array(li)
+                # if >1d list of floats\ints - this will work
+                if new_np.dtype in [float, np.float, np.float32, np.float64]:
+                    new_li = np.around(new_np, fp).tolist()
+            except TypeError as e:  # list has non ints\floats elements or uneven size ...
+                if warn:
+                    exception_error(e, real_exception=True)
     return new_li
 
 
