@@ -238,8 +238,8 @@ def to_str_test():
     print(mt.to_str(var=x, title='\tvery long int'))
 
     # FLOATS
-    f = 3.2
-    print(mt.to_str(var=f, title='\tsmall float'))
+    f = 3.4
+    print(mt.to_str(var=f, title='\tsmall float', fp=-1))
 
     f = 3.2123123
     print(mt.to_str(var=f, title='\tlong float(rounded 4 digits)', fp=4))
@@ -247,6 +247,7 @@ def to_str_test():
     f = 1234567890.223123123123123123
     print(mt.to_str(var=f, title='\tbig long float(rounded 3 digits)', fp=3))
 
+    # STRINGS
     s = 'hello world'
     print(mt.to_str(var=s, title='\tregular string'))
 
@@ -264,8 +265,8 @@ def to_str_test():
     print(mt.to_str(var=li, title='\tlist of ints(no metadata)', wm=False))
 
     li = [1, 3123123]
-    print(mt.to_str(var=li, title='\t1d list of ints(no data)', chars=None))
-    print(mt.to_str(var=li, title='\t1d list of ints(all data)', chars='all'))
+    print(mt.to_str(var=li, title='\t1d list of ints(no data)', chars=0))
+    print(mt.to_str(var=li, title='\t1d list of ints(all data)', chars=-1))
 
     li = [1.0000012323, 3123123.22454875123123]
     print(mt.to_str(var=li, title='\t1d list(rounded 7 digits)', fp=7))
@@ -294,10 +295,10 @@ def to_str_test():
 
     # NUMPY
     ni = np.array([4e-05, 6e-02], dtype=float)
-    print(mt.to_str(var=ni, title='\t1d np array', fp=2, rec=False))
+    print(mt.to_str(var=ni, title='\t1d np array(fp=5)', fp=5, rec=False))
 
     ni = np.array([1.0000012323, 3123123.22454875123123], dtype=float)
-    print(mt.to_str(var=ni, title='\t1d np array', fp=2, rec=False))
+    print(mt.to_str(var=ni, title='\t1d np array(fp=2)', fp=2, rec=False))
 
     ni = np.array([[1231.123122, 15.9], [3.0, 7.55], [4e-05, 6e-02]])
     print(mt.to_str(var=ni, title='\t2d np array', rec=True))
@@ -658,31 +659,37 @@ def reverse_tuple_or_list_test():
 
 def round_list_test():
     mt.get_function_name(ack=True, tabs=0)
-    li = [1.23123123, 12.123123123123123123, 1.2, 1.0]
-    print(mt.to_str(var=li, title='\torigin', fp=None))
-    print(mt.to_str(var=mt.round_list(li, fp=1), title='\tfp=1', fp=None))
-    print(mt.to_str(var=mt.round_list(li, fp=3), title='\tfp=3', fp=None))
-    l2 = [5e-05, 0.00014, 5e-10, 0.0001, 6e-07, 5e-05, 8e-05, 6e-05, 5e-05, 5e-05]
-    print(mt.to_str(var=l2, title='\torigin', fp=None))
-    print(mt.to_str(var=mt.round_list(l2, fp=5), title='\tfp=5', fp=None))
-    l2 = ['x', 'y', 'z']
-    print(mt.to_str(var=l2, title='\torigin', fp=None))
-    print(mt.to_str(var=mt.round_list(l2, fp=5, warn=True), title='\tfp=5', fp=None))
+    li = [1.23123123, 12.123123123123123123, 1.2, 1.0, 6e-06]
+    print(mt.to_str(var=li, title='\torigin', fp=-1))
+    print(mt.to_str(var=mt.round_list(li, fp=1), title='\tfp=1', fp=-1))
+    print(mt.to_str(var=mt.round_list(li, fp=6), title='\tfp=6', fp=-1))
+
+    li = [[1.23123123, 12.123123123123123123, 1.2, 1.0, 6e-06, 2]]
+    print(mt.to_str(var=li, title='\torigin', fp=-1))
+    print(mt.to_str(var=mt.round_list(li, fp=6), title='\tfp=6', fp=-1))
+
+    l2 = [5e-05, 0.00014, 5e-10, 0.0001, 6e-07, 5e-05, 8e-05, 6e-05, 5e-05, 5e-05, 2]
+    print(mt.to_str(var=l2, title='\torigin', fp=-1))
+    print(mt.to_str(var=mt.round_list(l2, fp=5), title='\tfp=5', fp=-1))
+
+    l2 = ['x', 'y', 'z', 0.3]
+    print(mt.to_str(var=l2, title='\torigin', fp=-1))
+    print(mt.to_str(var=mt.round_list(l2, fp=5, warn=True), title='\tfp=5', fp=-1))
     return
 
 
 def round_tuple_test():
     mt.get_function_name(ack=True, tabs=0)
     li = (1.23123123, 12.123123123123123123, 1.2, 1.0)
-    print(mt.to_str(var=li, title='\torigin', fp=None))
-    print(mt.to_str(var=mt.round_tuple(li, fp=1), title='\tfp=1', fp=None))
-    print(mt.to_str(var=mt.round_tuple(li, fp=3), title='\tfp=3', fp=None))
+    print(mt.to_str(var=li, title='\torigin', fp=-1))
+    print(mt.to_str(var=mt.round_tuple(li, fp=1), title='\tfp=1', fp=-1))
+    print(mt.to_str(var=mt.round_tuple(li, fp=3), title='\tfp=3', fp=-1))
     l2 = (5e-05, 0.00014, 5e-10, 0.0001, 6e-07, 5e-05, 8e-05, 6e-05, 5e-05, 5e-05)
-    print(mt.to_str(var=l2, title='\torigin', fp=None))
-    print(mt.to_str(var=mt.round_tuple(l2, fp=5), title='\tfp=5', fp=None))
+    print(mt.to_str(var=l2, title='\torigin', fp=-1))
+    print(mt.to_str(var=mt.round_tuple(l2, fp=5), title='\tfp=5', fp=-1))
     l2 = ('x', 'y', 'z')
-    print(mt.to_str(var=l2, title='\torigin', fp=None))
-    print(mt.to_str(var=mt.round_tuple(l2, fp=5, warn=True), title='\tfp=5', fp=None))
+    print(mt.to_str(var=l2, title='\torigin', fp=-1))
+    print(mt.to_str(var=mt.round_tuple(l2, fp=5, warn=True), title='\tfp=5', fp=-1))
     return
 
 
