@@ -773,10 +773,19 @@ MODELS_CONFIG = {
             15: 'leftWrist', 16: 'rightWrist', 17: 'leftPalm', 18: 'rightPalm', 19: 'leftIndex',
             20: 'rightIndex', 21: 'leftPinky', 22: 'rightPinky', 23: 'leftHip', 24: 'rightHip',
             25: 'leftKnee', 26: 'rightKnee', 27: 'leftAnkle', 28: 'rightAnkle', 29: 'leftHeel',
-            30: 'rightHeel', 31: 'leftFoot', 32: 'rightFoot', 33: 'midHip',
+            30: 'rightHeel', 31: 'leftFoot', 32: 'rightFoot'
             # don't think those are supported
-            # 34: 'forehead',35: 'leftThumb',36: 'leftHand',37: 'rightThumb',38: 'rightHand',
+            # 33: 'midHip', 34: 'forehead',35: 'leftThumb',36: 'leftHand',37: 'rightThumb',38: 'rightHand',
         },
+        'joint_colors': [
+            'red', 'magenta', 'lime', 'magenta', 'magenta',
+            'lime', 'magenta', 'lime', 'lime', 'lime',
+            'lime', 'darkorange', 'darkorange', 'yellow', 'yellow',
+            'darkorange', 'darkorange', 'aqua', 'aqua', 'lime',
+            'lime', 'yellow', 'yellow', 'aqua', 'aqua',
+            'magenta', 'magenta', 'aqua', 'aqua', 'magenta',
+            'magenta', 'aqua', 'aqua',
+        ],
         'pairs_indices': [
             [7, 3], [3, 2], [2, 1], [1, 0], [0, 9], [9, 10], [10, 0], [0, 4], [4, 5], [5, 6], [6, 8],
             [17, 15], [15, 13], [13, 11], [18, 16], [16, 14], [14, 12], [23, 25], [25, 27], [27, 29],
@@ -814,10 +823,19 @@ MODELS_CONFIG = {
             15: 'leftWrist', 16: 'rightWrist', 17: 'leftPalm', 18: 'rightPalm', 19: 'leftIndex',
             20: 'rightIndex', 21: 'leftPinky', 22: 'rightPinky', 23: 'leftHip', 24: 'rightHip',
             25: 'leftKnee', 26: 'rightKnee', 27: 'leftAnkle', 28: 'rightAnkle', 29: 'leftHeel',
-            30: 'rightHeel', 31: 'leftFoot', 32: 'rightFoot', 33: 'midHip',
+            30: 'rightHeel', 31: 'leftFoot', 32: 'rightFoot'
             # don't think those are supported
-            # 34: 'forehead',35: 'leftThumb',36: 'leftHand',37: 'rightThumb',38: 'rightHand',
+            # 33: 'midHip', 34: 'forehead',35: 'leftThumb',36: 'leftHand',37: 'rightThumb',38: 'rightHand',
         },
+        'joint_colors': [
+            'red', 'magenta', 'lime', 'magenta', 'magenta',
+            'lime', 'magenta', 'lime', 'lime', 'lime',
+            'lime', 'darkorange', 'darkorange', 'yellow', 'yellow',
+            'darkorange', 'darkorange', 'aqua', 'aqua', 'lime',
+            'lime', 'yellow', 'yellow', 'aqua', 'aqua',
+            'magenta', 'magenta', 'aqua', 'aqua', 'magenta',
+            'magenta', 'aqua', 'aqua',
+        ],
         'pairs_indices_colors': [
             'lime', 'lime', 'lime', 'lime', 'lime',
             'lime', 'lime', 'lime', 'lime', 'lime',
@@ -858,10 +876,19 @@ MODELS_CONFIG = {
             15: 'leftWrist', 16: 'rightWrist', 17: 'leftPalm', 18: 'rightPalm', 19: 'leftIndex',
             20: 'rightIndex', 21: 'leftPinky', 22: 'rightPinky', 23: 'leftHip', 24: 'rightHip',
             25: 'leftKnee', 26: 'rightKnee', 27: 'leftAnkle', 28: 'rightAnkle', 29: 'leftHeel',
-            30: 'rightHeel', 31: 'leftFoot', 32: 'rightFoot', 33: 'midHip',
+            30: 'rightHeel', 31: 'leftFoot', 32: 'rightFoot'
             # don't think those are supported
-            # 34: 'forehead',35: 'leftThumb',36: 'leftHand',37: 'rightThumb',38: 'rightHand',
+            # 33: 'midHip', 34: 'forehead',35: 'leftThumb',36: 'leftHand',37: 'rightThumb',38: 'rightHand',
         },
+        'joint_colors': [
+            'red', 'magenta', 'lime', 'magenta', 'magenta',
+            'lime', 'magenta', 'lime', 'lime', 'lime',
+            'lime', 'darkorange', 'darkorange', 'yellow', 'yellow',
+            'darkorange', 'darkorange', 'aqua', 'aqua', 'lime',
+            'lime', 'yellow', 'yellow', 'aqua', 'aqua',
+            'magenta', 'magenta', 'aqua', 'aqua', 'magenta',
+            'magenta', 'aqua', 'aqua',
+        ],
         'pairs_indices': [
             [7, 3], [3, 2], [2, 1], [1, 0], [0, 9], [9, 10], [10, 0], [0, 4], [4, 5], [5, 6], [6, 8],
             [17, 15], [15, 13], [13, 11], [18, 16], [16, 14], [14, 12], [23, 25], [25, 27], [27, 29],
@@ -898,6 +925,12 @@ MODELS_CONFIG = {
             10: 'rightWrist', 11: 'leftHip', 12: 'rightHip', 13: 'leftKnee', 14: 'rightKnee',
             15: 'leftAnkle', 16: 'rightAnkle',
         },
+        'joint_colors': [
+            'red', 'magenta', 'magenta', 'lime', 'lime',
+            'darkorange', 'darkorange', 'yellow', 'yellow', 'darkorange',
+            'darkorange', 'aqua', 'aqua', 'magenta', 'magenta',
+            'aqua', 'aqua'
+        ],
         'pairs_indices': [
             [5, 6], [5, 7], [7, 9], [5, 11], [6, 8],
             [8, 10], [6, 12], [11, 12], [11, 13], [13, 15],
@@ -927,9 +960,17 @@ MODELS_CONFIG = {
         'job': Jobs.POSE_DETECTION.value,
         'family': DnnFamily.Caffe.value,
         'joint_names': {
-            0: 'Head', 1: 'Neck', 2: 'RShoulder', 3: 'RElbow', 4: 'RWrist', 5: 'LShoulder', 6: 'LElbow', 7: 'LWrist',
-            8: 'RHip', 9: 'RKnee', 10: 'RAnkle', 11: 'LHip', 12: 'LKnee', 13: 'LAnkle', 14: 'Chest', 15: 'Background'
+            0: 'Head', 1: 'Neck', 2: 'RShoulder', 3: 'RElbow', 4: 'RWrist',
+            5: 'LShoulder', 6: 'LElbow', 7: 'LWrist', 8: 'RHip', 9: 'RKnee',
+            10: 'RAnkle', 11: 'LHip', 12: 'LKnee', 13: 'LAnkle', 14: 'Chest',
+            15: 'Background'
         },
+        'joint_colors': [
+            'darkorange', 'red', 'darkorange', 'yellow', 'darkorange',
+            'darkorange', 'yellow', 'darkorange', 'lime', 'aqua',
+            'magenta', 'lime', 'aqua', 'magenta', 'aqua',
+            'black'
+        ],
         'pairs_indices': [
             [0, 1], [1, 2], [2, 3], [3, 4], [1, 5],
             [5, 6], [6, 7], [1, 14], [14, 8], [8, 9],
@@ -967,10 +1008,17 @@ MODELS_CONFIG = {
         'job': Jobs.POSE_DETECTION.value,
         'family': DnnFamily.Caffe.value,
         'joint_names': {
-            0: 'Nose', 1: 'Neck', 2: 'RShoulder', 3: 'RElbow', 4: 'RWrist', 5: 'LShoulder', 6: 'LElbow', 7: 'LWrist',
-            8: 'RHip', 9: 'RKnee', 10: 'RAnkle', 11: 'LHip', 12: 'LKnee', 13: 'LAnkle', 14: 'REye', 15: 'LEye',
-            16: 'REar', 17: 'LEar', 18: 'Background',
+            0: 'Nose', 1: 'Neck', 2: 'RShoulder', 3: 'RElbow', 4: 'RWrist',
+            5: 'LShoulder', 6: 'LElbow', 7: 'LWrist', 8: 'RHip', 9: 'RKnee',
+            10: 'RAnkle', 11: 'LHip', 12: 'LKnee', 13: 'LAnkle', 14: 'REye',
+            15: 'LEye', 16: 'REar', 17: 'LEar', 18: 'Background',
         },
+        'joint_colors': [
+            'red', 'red', 'darkorange', 'yellow', 'darkorange',
+            'darkorange', 'yellow', 'darkorange', 'lime', 'aqua',
+            'magenta', 'lime', 'aqua', 'magenta', 'blue',
+            'blue', 'aqua', 'aqua', 'black'
+        ],
         'pairs_indices': [
             [1, 2], [1, 5], [2, 3], [3, 4], [5, 6],
             [6, 7], [1, 8], [8, 9], [9, 10], [1, 11],
@@ -980,8 +1028,8 @@ MODELS_CONFIG = {
         'pairs_indices_colors': [
             'darkorange', 'darkorange', 'yellow', 'darkorange', 'yellow',
             'darkorange', 'lime', 'aqua', 'magenta', 'lime',
-            'aqua', 'magenta', 'red', 'blue', 'deepskyblue',
-            'blue', 'deepskyblue'
+            'aqua', 'magenta', 'red', 'blue', 'aqua',
+            'blue', 'aqua'
         ],
         'in_dims': (368, 368),
         'scalefactor': 1 / 255,
@@ -1011,10 +1059,17 @@ MODELS_CONFIG = {
         'job': Jobs.POSE_DETECTION.value,
         'family': DnnFamily.Caffe.value,
         'joint_names': {
-            0: 'Nose', 1: 'Neck', 2: 'RShoulder', 3: 'RElbow', 4: 'RWrist', 5: 'LShoulder', 6: 'LElbow', 7: 'LWrist',
-            8: 'RHip', 9: 'RKnee', 10: 'RAnkle', 11: 'LHip', 12: 'LKnee', 13: 'LAnkle', 14: 'REye', 15: 'LEye',
-            16: 'REar', 17: 'LEar',
+            0: 'Nose', 1: 'Neck', 2: 'RShoulder', 3: 'RElbow', 4: 'RWrist',
+            5: 'LShoulder', 6: 'LElbow', 7: 'LWrist', 8: 'RHip', 9: 'RKnee',
+            10: 'RAnkle', 11: 'LHip', 12: 'LKnee', 13: 'LAnkle', 14: 'REye',
+            15: 'LEye', 16: 'REar', 17: 'LEar'
         },
+        'joint_colors': [
+            'red', 'red', 'darkorange', 'yellow', 'darkorange',
+            'darkorange', 'yellow', 'darkorange', 'lime', 'aqua',
+            'magenta', 'lime', 'aqua', 'magenta', 'blue',
+            'blue', 'aqua', 'aqua'
+        ],
         'pairs_indices': [
             [1, 2], [1, 5], [2, 3], [3, 4], [5, 6],
             [6, 7], [1, 8], [8, 9], [9, 10], [1, 11],
@@ -1024,8 +1079,8 @@ MODELS_CONFIG = {
         'pairs_indices_colors': [
             'darkorange', 'darkorange', 'yellow', 'darkorange', 'yellow',
             'darkorange', 'lime', 'aqua', 'magenta', 'lime',
-            'aqua', 'magenta', 'red', 'blue', 'deepskyblue',
-            'blue', 'deepskyblue'
+            'aqua', 'magenta', 'red', 'blue', 'aqua',
+            'blue', 'aqua'
         ],
         'pafs_indices': [
             # index of pafs corresponding to the POSE_PAIRS
@@ -1066,11 +1121,21 @@ MODELS_CONFIG = {
         'job': Jobs.POSE_DETECTION.value,
         'family': DnnFamily.Caffe.value,
         'joint_names': {
-            0: 'Nose', 1: 'Neck', 2: 'RShoulder', 3: 'RElbow', 4: 'RWrist', 5: 'LShoulder', 6: 'LElbow', 7: 'LWrist',
-            8: 'MidHip', 9: 'RHip', 10: 'RKnee', 11: 'RAnkle', 12: 'LHip', 13: 'LKnee', 14: 'LAnkle', 15: 'REye',
-            16: 'LEye', 17: 'REar', 18: 'LEar', 19: 'LBigToe', 20: 'LSmallToe', 21: 'LHeel', 22: 'RBigToe',
-            23: 'RSmallToe', 24: 'RHeel', 25: 'Background',
+            0: 'Nose', 1: 'Neck', 2: 'RShoulder', 3: 'RElbow', 4: 'RWrist',
+            5: 'LShoulder', 6: 'LElbow', 7: 'LWrist', 8: 'MidHip', 9: 'RHip',
+            10: 'RKnee', 11: 'RAnkle', 12: 'LHip', 13: 'LKnee', 14: 'LAnkle',
+            15: 'REye', 16: 'LEye', 17: 'REar', 18: 'LEar', 19: 'LBigToe',
+            20: 'LSmallToe', 21: 'LHeel', 22: 'RBigToe', 23: 'RSmallToe', 24: 'RHeel',
+            25: 'Background',
         },
+        'joint_colors': [  # TODO fix on a clearer picture
+            'red', 'red', 'darkorange', 'yellow', 'darkorange',
+            'darkorange', 'yellow', 'darkorange', 'lime', 'aqua',
+            'magenta', 'aqua', 'aqua', 'magenta', 'aqua',
+            'lime', 'lime', 'magenta', 'magenta', 'blue',
+            'magenta', 'lime', 'aqua', 'magenta', 'blue',
+            'blue',
+        ],
         'pairs_indices': [
             [1, 0], [1, 2], [1, 5], [2, 3], [3, 4],
             [5, 6], [6, 7], [0, 15], [15, 17], [0, 16],
@@ -1122,6 +1187,14 @@ MODELS_CONFIG = {
             13: 'ringBase', 14: 'ringMid1', 15: 'ringMid2', 16: 'ringNail',
             17: 'pinkyBase', 18: 'pinkyMid1', 19: 'pinkyMid2', 20: 'pinkyNail',
         },
+        'joint_colors': [
+            'red',
+            'darkorange', 'aqua', 'lime', 'yellow',
+            'darkorange', 'aqua', 'lime', 'yellow',
+            'darkorange', 'aqua', 'lime', 'yellow',
+            'darkorange', 'aqua', 'lime', 'yellow',
+            'darkorange', 'aqua', 'lime', 'yellow',
+        ],
         'pairs_indices': [
             [0, 1], [1, 2], [2, 3], [3, 4],  # thumb
             [0, 5], [5, 6], [6, 7], [7, 8],  # index
