@@ -25,10 +25,10 @@ def get_object_detection_models(ack: bool = False, tabs: int = 1) -> list:
 
 class OdBaseModel(BaseModel):
     DEFAULT_COLOR_DICT = {
-        'bbox': 'r',  # object box
-        'label_bbox': 'black',  # label background
-        'text': 'white',  # label text
-        'sub_image': 'blue',  # label sub image
+        'label_bbox': 'black',  # if draw_labels - text bg color
+        'text': 'white',  # if draw_labels - text bg color
+        'sub_image': 'blue',  # if draw_sub_image - sub image bbox color
+        'default_bbox': 'red',  # bbox over the detection
     }
 
     def __init__(
@@ -74,12 +74,14 @@ class OdBaseModel(BaseModel):
         exit(-1)
         return []
 
-    @staticmethod
     def draw_detections(
+            self,
             detections: list,
             cv_img: np.array,
-            colors_d: dict,
-            draw_labels: bool,
+            colors_d: dict = None,
+            draw_labels: bool = False,
+            draw_tl_image: bool = False,
+            draw_sub_image: bool = False
     ) -> None:
         """
         :param detections: output of self.classify_cv_img() on od models
@@ -89,15 +91,22 @@ class OdBaseModel(BaseModel):
             text color
             if class_id_bbox exist - color the bbox of that class in the given color
             e.g. colors_d={
-                    'bbox': 'r',
-                    'label_bbox': 'black',
-                    'text': 'white',
-                    'person_bbox': 'lightgreen', # custom color per class person
+                    'label_bbox': 'black',  # if draw_labels - text bg color
+                    'text': 'white',  # if draw_labels - text bg color
+                    'sub_image': 'blue',  # if draw_sub_image - sub image bbox color
+                    'default_bbox': 'red',  # bbox over the detection
+                    'person_bbox': 'black', # custom color per class person
+                    'dog_bbox': 'lime',  # custom color per class dog
+                    'cat_bbox': 'magenta',  # custom color per class cat
                 },
         :param cv_img: the same that was given input to self.classify_cv_img()
         :param draw_labels: draw label(label_bbox and text on it) on the bbox
+        :param draw_tl_image: draw traffic light if exists - has colors in it
+        :param draw_sub_image: draw sub image if exists
         :return:
         """
+        if colors_d is None:
+            colors_d = self.DEFAULT_COLOR_DICT
         for detection in detections:
             label = detection['label']
             score_percentage = detection['score_percentage']
@@ -108,27 +117,27 @@ class OdBaseModel(BaseModel):
             traffic_light_d = detection['traffic_light'] if 'traffic_light' in detection else {}
             bbox_sub_image_d = detection['bbox_sub_image'] if 'bbox_sub_image' in detection else None
 
-            # check custom color for this class
-            k = '{}_bbox'.format(label)
+            # DRAW BBOX
+            k = '{}_bbox'.format(label)  # check custom color for this class
             color_bgr = pyplt.get_BGR_color(colors_d[k]) if k in colors_d else pyplt.get_BGR_color(
-                colors_d['bbox'])
+                colors_d['default_bbox'])
             cv2.rectangle(img=cv_img, pt1=(x0, y0), pt2=(x1, y1), color=color_bgr, thickness=2)
 
-            for loc, point_and_color in traffic_light_d.items():
-                cv2.circle(cv_img, center=tuple(point_and_color['point']), radius=2,
-                           color=pyplt.get_BGR_color(point_and_color['color']), thickness=-1)
+            if draw_tl_image:  # DRAW TL
+                for loc, point_and_color in traffic_light_d.items():
+                    cv2.circle(cv_img, center=tuple(point_and_color['point']), radius=2,
+                               color=pyplt.get_BGR_color(point_and_color['color']), thickness=-1)
 
-            if bbox_sub_image_d is not None:
+            if draw_sub_image and bbox_sub_image_d is not None:  # DRAW sub image
                 pt1 = (bbox_sub_image_d['x0'], bbox_sub_image_d['y0'])
                 pt2 = (bbox_sub_image_d['x1'], bbox_sub_image_d['y1'])
                 cv2.rectangle(img=cv_img, pt1=pt1, pt2=pt2, color=pyplt.get_BGR_color(colors_d['sub_image']),
                               thickness=1)  # sub image
 
             if draw_labels:
-                label_conf = '{}({}%)'.format(label, score_percentage)
+                label_conf = '{}({}%)'.format(label, score_percentage)  # DRAW labels
                 cvt.add_text(cv_img, header=label_conf, pos=(x0, y1), text_color=colors_d['text'], with_rect=True,
                              bg_color=colors_d['label_bbox'], bg_font_scale=2)
-
         return
 
     @staticmethod
@@ -182,36 +191,36 @@ class OdBaseModel(BaseModel):
         :param detections:
         :param cv_img:
         :param bbox_image_p: dict that specify how much from the bbox to save
-                bbox_image_p={  # all bbox
-                    'x_start': 0,
-                    'x_end': 1,
-                    'y_start': 0,
-                    'y_end': 1,
-                },
-                bbox_image_p={  # sub bbox
-                    'x_start': 0.5,  # start from middle
-                    'x_end': 0.9,     # go to the right until 90% of the width
-                    'y_start': 0,  # 0 start from the bottom
-                    'y_end': 0.4,  # end at 40% from bottom
-                },
+                bbox_image_p = {  # all bbox
+                    'x_left_start': 0,
+                    'x_left_end': 1,
+                    'y_top_start': 0,
+                    'y_top_end': 1,
+                }
+                bbox_image_p = {  # sub bbox
+                    'x_left_start': 0.2,  x left: start from 20% of the image
+                    'x_left_end': 0.9, x right: end at 90%
+                    'y_top_start': 0.2, y top: start at 20%
+                    'y_top_end': 0.6, y bottom: end at 60%
+                }
         :return: for each detection in detections: add entry 'bbox_sub_image' with a dict with keys image,x0,x1,y0,y1
                     if you imshow - you will get the bbox of the detection (according to bbox_image_p)
         """
         for detection_d in detections:
             # label = detection_d['label']
             # confidence = detection_d['score_percentage']
-            x0 = detection_d['bbox']['x0']
-            y0 = detection_d['bbox']['y0']
-            x1 = detection_d['bbox']['x1']
-            y1 = detection_d['bbox']['y1']
-            y_dist = y0 - y1  # image is flipped on y axis
+            bbox = detection_d['bbox']
+            x0, x1 = bbox['x0'], bbox['x1']
+            y0, y1 = bbox['y0'], bbox['y1']
+
+            y_dist = y1 - y0
             x_dist = x1 - x0
             # prepare sub sub image (a part of the bbox)
-            # y1 is the bottom
-            sub_y0 = int(y1 + bbox_image_p['y_start'] * y_dist)
-            sub_y1 = int(y1 + bbox_image_p['y_end'] * y_dist)
-            sub_x0 = int(x0 + bbox_image_p['x_start'] * x_dist)
-            sub_x1 = int(x0 + bbox_image_p['x_end'] * x_dist)
+            # the origin is left - top. (x0,y0) is top left. (x1,y1) is bottom right
+            sub_y0 = int(y0 + bbox_image_p['y_top_start'] * y_dist)
+            sub_y1 = int(y0 + bbox_image_p['y_top_end'] * y_dist)
+            sub_x0 = int(x0 + bbox_image_p['x_left_start'] * x_dist)
+            sub_x1 = int(x0 + bbox_image_p['x_left_end'] * x_dist)
             detection_d['bbox_sub_image'] = {
                 'image': cv_img[sub_y0:sub_y1, sub_x0:sub_x1].tolist(),
                 'x0': sub_x0,
@@ -219,6 +228,7 @@ class OdBaseModel(BaseModel):
                 'x1': sub_x1,
                 'y1': sub_y1,
             }
+            # cvt.display_open_cv_image(detection_d['bbox_sub_image']['image'])
         return detections
 
 
@@ -469,63 +479,6 @@ class TflOdModel(OdBaseModel):
         )
         return detections
 
-    @staticmethod
-    def draw_detections(
-            detections: list,
-            cv_img: np.array,
-            colors_d: dict = None,
-            draw_labels: bool = True,
-    ) -> None:
-        """
-        :param detections: output of self.classify_cv_img() on od models
-        :param colors_d: colors in str form:
-            bbox color
-            label_bbox color
-            text color
-            if class_id_bbox exist - color the bbox of that class in the given color
-                e.g. colors_d={
-                        'bbox': 'r',
-                        'label_bbox': 'black',
-                        'text': 'white',
-                        'person_bbox': 'lightgreen',
-                    },
-        :param cv_img: the same that was given input to self.classify_cv_img()
-        :param draw_labels: draw label(label_bbox and text on it) on the bbox
-        :return:
-        """
-        if colors_d is None:
-            colors_d = OdBaseModel.DEFAULT_COLOR_DICT
-        OdBaseModel.draw_detections(
-            detections=detections,
-            cv_img=cv_img,
-            colors_d=colors_d,
-            draw_labels=draw_labels
-        )
-        return
-
-    @staticmethod
-    def add_traffic_light_to_detections(detections: list, traffic_light_p: dict) -> list:
-        """
-        see add_traffic_light_to_detections
-        """
-        detections = OdBaseModel.add_traffic_light_to_detections(
-            detections=detections,
-            traffic_light_p=traffic_light_p
-        )
-        return detections
-
-    @staticmethod
-    def add_sub_sub_image_to_detection(detections: list, cv_img: np.array, bbox_image_p: dict) -> list:
-        """
-        see add_sub_sub_image_to_detection
-        """
-        detections = OdBaseModel.add_sub_sub_image_to_detection(
-            detections=detections,
-            cv_img=cv_img,
-            bbox_image_p=bbox_image_p
-        )
-        return detections
-
 
 class Cv2OdModel(OdBaseModel):
     def __init__(self,
@@ -766,60 +719,3 @@ class Cv2OdModel(OdBaseModel):
                     print(d_msg.format(tabs * '\t', i, label, score_percentage, (x0, y0), (x1, y1)))
 
         return detections
-
-    @staticmethod
-    def draw_detections(
-            detections: list,
-            cv_img: np.array,
-            colors_d: dict = None,
-            draw_labels: bool = True,
-    ) -> None:
-        """
-        :param detections: output of self.classify_cv_img() on od models
-        :param colors_d: colors in str form:
-            bbox color
-            label_bbox color
-            text color
-            if class_id_bbox exist - color the bbox of that class in the given color
-                e.g. colors_d={
-                        'bbox': 'r',
-                        'label_bbox': 'black',
-                        'text': 'white',
-                        'person_bbox': 'lightgreen',
-                    },
-        :param cv_img: the same that was given input to self.classify_cv_img()
-        :param draw_labels: draw label(label_bbox and text on it) on the bbox
-        :return:
-        """
-        if colors_d is None:
-            colors_d = OdBaseModel.DEFAULT_COLOR_DICT
-        OdBaseModel.draw_detections(
-            detections=detections,
-            cv_img=cv_img,
-            colors_d=colors_d,
-            draw_labels=draw_labels
-        )
-        return
-
-    @staticmethod
-    def add_traffic_light_to_detections(detections: list, traffic_light_p: dict) -> list:
-        """
-        see add_traffic_light_to_detections
-        """
-        detections = OdBaseModel.add_traffic_light_to_detections(
-            detections=detections,
-            traffic_light_p=traffic_light_p
-        )
-        return detections
-
-    @staticmethod
-    def add_sub_sub_image_to_detection(detections: list, cv_img: np.array, bbox_image_p: dict) -> list:
-        """
-        see add_sub_sub_image_to_detection
-        """
-        detections = OdBaseModel.add_sub_sub_image_to_detection(
-            detections=detections,
-            cv_img=cv_img,
-            bbox_image_p=bbox_image_p
-        )
-        return detections
