@@ -24,9 +24,9 @@ def get_pose_detection_models(ack: bool = False, tabs: int = 1) -> list:
 
 class PdBaseModel(BaseModel):
     DEFAULT_COLOR_DICT = {
-        'joint_c': 'red',  # joint color
-        'edge_c': 'lightgreen',  # line color
-        'text_c': 'white',  # label index color
+        'bbox_c': 'blue',
+        'sub_image_c': 'darkorange',
+        'text_c': 'white',
     }
     NOT_FOUND_VALUE = -1
     NOT_FOUND_PAIR = [NOT_FOUND_VALUE, NOT_FOUND_VALUE]
@@ -36,6 +36,7 @@ class PdBaseModel(BaseModel):
             save_load_dir: str,
             model_name: str,
             allowed_joint_names: list = None,
+            min_p_valid_joints: float = 0.3,
     ):
         super().__init__(save_load_dir=save_load_dir, model_name=model_name)
         if not self.model_name_valid(model_name):
@@ -43,9 +44,12 @@ class PdBaseModel(BaseModel):
         self.model_cfg = cfg.MODELS_CONFIG[model_name]
         self.joint_names = self.model_cfg['joint_names']
         self.pairs_indices = self.model_cfg['pairs_indices']
-        self.pairs_indices_colors = self.model_cfg['pairs_indices_colors']
+        # grab default colors and convert to bgr
+        self.pairs_indices_colors = [pyplt.get_BGR_color(c) for c in self.model_cfg['pairs_indices_colors']]
+        self.joint_colors = [pyplt.get_BGR_color(c) for c in self.model_cfg['joint_colors']]
         self.allowed_joint_names = list(
             self.joint_names.values()) if allowed_joint_names is None else allowed_joint_names
+        self.min_p_valid_joints = min_p_valid_joints
         return
 
     # noinspection PyUnusedLocal
@@ -82,51 +86,166 @@ class PdBaseModel(BaseModel):
             detections: list,
             cv_img: np.array,
             colors_d: dict,
-            draw_labels: bool,
+            draw_joints: bool = True,
+            draw_labels: bool = False,
+            draw_edges: bool = False,
+            draw_bbox: bool = False,
+            draw_sub_image: bool = False
     ) -> None:
         """
         :param detections: output of self.classify_cv_img()
         :param colors_d: colors in str form:
-            bbox color
-            label_bbox color
-            text color
+            bbox_c: bbox color
+            sub_image_c: sub image color
+            text_c: text color
+            joints_c: str or list of size self.joint_names. if None - has default in cfg
+            edge_c: str or list of size self.pairs_indices. if None - has default in cfg
             e.g. colors_d={
-                    'joint_c': 'red',
-                    'text_c': 'white',
+                    'bbox_c': 'blue'
+                    'sub_image_c': 'black'
+                    'text_c': 'black',
+                    'joints_c': str or list of size self.joint_names. if None - has default in cfg
+                    'edge_c': str or list of size self.pairs_indices. if None - has default in cfg
                 },
         :param cv_img: the same that was given input to self.classify_cv_img()
-        :param draw_labels: draw part index
+        :param draw_joints: draw joints
+        :param draw_labels: draw joint ids (valid if draw_joints True)
+        :param draw_edges: draw edges between joints
+        :param draw_bbox: draw bbox around poses
+        :param draw_sub_image: draw sub image from the bbox around the poses
         :return:
         """
         if colors_d is None:
             colors_d = self.DEFAULT_COLOR_DICT
-        joint_c = pyplt.get_BGR_color(colors_d['joint_c'])
-        text_c = colors_d['text_c']
-        for detection in detections:  # each detection is a pose - currently supports just 1
+
+        for detection in detections:  # each detection is a pose
             names = detection['joint_names_list']
             ids = detection['joint_ids_list']
             xys = detection['joint_x_y_list']
             # zs = detection['joint_z_list'] if 'joint_z_list' in detection else [self.NOT_FOUND_VALUE] * len(names)
             scores = detection['score_percentages_list']
+            pose_bbox = detection['bbox']
+            bbox_sub_image_d = detection['bbox_sub_image'] if 'bbox_sub_image' in detection else None
 
-            # DRAW LINES: lines connecting the edges
-            for i, pair in enumerate(self.pairs_indices):
-                partA, partB = pair
-                if xys[partA] != self.NOT_FOUND_PAIR and xys[partB] != self.NOT_FOUND_PAIR:
-                    edge_c = pyplt.get_BGR_color(self.pairs_indices_colors[i])
-                    cv2.line(cv_img, pt1=tuple(xys[partA]), pt2=tuple(xys[partB]), color=edge_c, thickness=2)
+            if draw_bbox:  # DRAW BBOX
+                color_bgr = pyplt.get_BGR_color(colors_d['bbox_c'])
+                pt1 = (pose_bbox['x0'], pose_bbox['y0'])
+                pt2 = (pose_bbox['x1'], pose_bbox['y1'])
+                cv2.rectangle(img=cv_img, pt1=pt1, pt2=pt2, color=color_bgr, thickness=2)
+
+            if draw_sub_image and bbox_sub_image_d is not None:  # DRAW sub image
+                color_bgr = pyplt.get_BGR_color(colors_d['sub_image_c'])
+                pt1 = (bbox_sub_image_d['x0'], bbox_sub_image_d['y0'])
+                pt2 = (bbox_sub_image_d['x1'], bbox_sub_image_d['y1'])
+                cv2.rectangle(img=cv_img, pt1=pt1, pt2=pt2, color=color_bgr, thickness=1)  # sub image
+
+            # DRAW EDGES: lines connecting the edges
+            if draw_edges:
+                if 'edge_c' in colors_d:
+                    edges_colors = colors_d['edge_c']
+                    if mt.is_str(edges_colors):  # 1 color for all
+                        edges_colors = [pyplt.get_BGR_color(edges_colors)] * len(self.pairs_indices)
+                    else:  # list of colors - must be in len(self.joint_names)
+                        edges_colors = [pyplt.get_BGR_color(c) for c in edges_colors]
+                else:  # take default colors
+                    edges_colors = self.pairs_indices_colors
+                for pair, bgr_c in zip(self.pairs_indices, edges_colors):
+                    partA, partB = pair
+                    if xys[partA] != self.NOT_FOUND_PAIR and xys[partB] != self.NOT_FOUND_PAIR:
+                        cv2.line(cv_img, pt1=tuple(xys[partA]), pt2=tuple(xys[partB]), color=bgr_c, thickness=2)
 
             # DRAW JOINTS: circle and joint id if asked
-            for name, jid, xy, score in zip(names, ids, xys, scores):
-                if xy != self.NOT_FOUND_PAIR:
-                    cv2.circle(cv_img, center=tuple(xy), radius=3, color=joint_c, thickness=-1)
-                    if draw_labels:
-                        label_xy = (xy[0] - 5, xy[1])
-                        label = '{}'.format(jid)
-                        cvt.add_text(cv_img, header=label, pos=label_xy, text_color=text_c, with_rect=False,
-                                     bg_font_scale=2)
+            if draw_joints:
+                text_color_str = colors_d['text_c']
+                if 'joint_colors' in colors_d:
+                    joints_colors = colors_d['joint_colors']
+                    if mt.is_str(joints_colors):  # 1 color for all
+                        joints_colors = [pyplt.get_BGR_color(joints_colors)] * len(self.joint_names)
+                    else:  # list of colors - must be in len(self.joint_names)
+                        joints_colors = [pyplt.get_BGR_color(c) for c in joints_colors]
+                else:  # take default colors
+                    joints_colors = self.joint_colors
+
+                for name, jid, xy, score, bgr_c in zip(names, ids, xys, scores, joints_colors):
+                    if xy != self.NOT_FOUND_PAIR:
+                        cv2.circle(cv_img, center=tuple(xy), radius=5, color=bgr_c, thickness=-1)
+                        if draw_labels:
+                            label_xy = (xy[0] - 5, xy[1])
+                            label = '{}'.format(jid)
+                            cvt.add_text(cv_img, header=label, pos=label_xy, text_color=text_color_str, with_rect=False,
+                                         bg_font_scale=2)
         return
 
+    @staticmethod
+    def get_bbox_dict(joint_x_y_list: list) -> dict:
+        x0, y0, x1, y1 = np.inf, np.inf, -1, -1
+        for x_y in joint_x_y_list:
+            if x_y != PdBaseModel.NOT_FOUND_PAIR:
+                x, y = x_y
+                if x0 > x:
+                    x0 = x
+                elif x1 < x:
+                    x1 = x
+                if y0 > y:
+                    y0 = y
+                elif y1 < y:
+                    y1 = y
+        bbox = {
+            #  pt1 = (x0, y0)  # obj frame top left corner
+            #  pt2 = (x1, y1)  # obj frame bottom right corner
+            'x0': x0,
+            'y0': y0,
+            'x1': x1,
+            'y1': y1,
+        }
+        return bbox
+
+    @staticmethod
+    def add_sub_sub_image_to_detection(detections: list, cv_img: np.array, bbox_image_p: dict) -> list:
+        """
+        :param detections:
+        :param cv_img:
+        :param bbox_image_p: dict that specify how much from the bbox to save
+                bbox_image_p = {  # all bbox
+                    'x_left_start': 0,
+                    'x_left_end': 1,
+                    'y_top_start': 0,
+                    'y_top_end': 1,
+                }
+                bbox_image_p = {  # sub bbox
+                    'x_left_start': 0.2,  x left: start from 20% of the image
+                    'x_left_end': 0.9, x right: end at 90%
+                    'y_top_start': 0.2, y top: start at 20%
+                    'y_top_end': 0.6, y bottom: end at 60%
+                }
+        :return: for each detection in detections: add entry 'bbox_sub_image' with a dict with keys image,x0,x1,y0,y1
+                    if you imshow - you will get the bbox of the detection (according to bbox_image_p)
+        """
+        for detection_d in detections:
+            # label = detection_d['label']
+            # confidence = detection_d['score_percentage']
+            bbox = detection_d['bbox']
+            x0, x1 = bbox['x0'], bbox['x1']
+            y0, y1 = bbox['y0'], bbox['y1']
+
+            y_dist = y1 - y0
+            x_dist = x1 - x0
+            # prepare sub sub image (a part of the bbox)
+            # the origin is left - top. (x0,y0) is top left. (x1,y1) is bottom right
+            sub_y0 = int(y0 + bbox_image_p['y_top_start'] * y_dist)
+            sub_y1 = int(y0 + bbox_image_p['y_top_end'] * y_dist)
+            sub_x0 = int(x0 + bbox_image_p['x_left_start'] * x_dist)
+            sub_x1 = int(x0 + bbox_image_p['x_left_end'] * x_dist)
+            detection_d['bbox_sub_image'] = {
+                'image': cv_img[sub_y0:sub_y1, sub_x0:sub_x1].tolist(),
+                'x0': sub_x0,
+                'y0': sub_y0,
+                'x1': sub_x1,
+                'y1': sub_y1,
+            }
+            # cvt.display_open_cv_image(detection_d['bbox_sub_image']['image'])
+        return detections
+
 
 class TflPdModel(PdBaseModel):
     def __init__(
@@ -135,6 +254,7 @@ class TflPdModel(PdBaseModel):
             model_name: str,
             threshold: float = None,
             allowed_joint_names: list = None,
+            min_p_valid_joints: float = 0.3,
             check_type: bool = True
     ):
         """
@@ -142,10 +262,15 @@ class TflPdModel(PdBaseModel):
         :param model_name: valid name in MODEL_CONF.keys()
         :param threshold: only detection above this threshold will be pass first filter
         :param allowed_joint_names: joint_names to track from the joint_names of the model
+        :param min_p_valid_joints:
+            let x=min_p_valid_joints*len(allowed_joint_names)
+            to keep a pose: we need max(x,2) joints found
+        :param check_type:
         example:
         see:
         """
-        super().__init__(save_load_dir=save_load_dir, model_name=model_name, allowed_joint_names=allowed_joint_names)
+        super().__init__(save_load_dir=save_load_dir, model_name=model_name, allowed_joint_names=allowed_joint_names,
+                         min_p_valid_joints=min_p_valid_joints)
         if check_type and not self.model_type_valid(self.model_cfg['model_type'], cfg.ModelType.PdTflNormal.value):
             exit(-1)
         if threshold is not None:
@@ -180,7 +305,7 @@ class TflPdModel(PdBaseModel):
         string = '{}{}'.format(tabs_s, mt.add_color(string='TflPdModel:', ops='underlined'))
         string += '\n\t{}name= {} (size {})'.format(tabs_s, self.model_name, self.model_size)
         string += '\n\t{}local_path= {}'.format(tabs_s, self.local_path)
-        string += '\n\t{}{}'.format(tabs_s, mt.to_str(self.allowed_joint_names, 'allowed_classes'))
+        string += '\n\t{}{}'.format(tabs_s, mt.to_str(self.allowed_joint_names, 'allowed_joint_names'))
         string += '\n{}'.format(mt.dict_as_table(self.model_cfg, title='cfg', fp=6, ack=False, tabs=tabs + 1))
         return string
 
@@ -250,7 +375,9 @@ class TflPdModel(PdBaseModel):
                 'joint_x_y_list': [],
                 'joint_z_list': [],
                 'score_percentages_list': [],
+                'bbox': {}
             }
+            valid_joints_found = 0  # max is len(self.allowed_joint_names)
             for joint_id, joint_name in self.joint_names.items():
                 detection_d['joint_names_list'].append(joint_name)
                 detection_d['joint_ids_list'].append(joint_id)
@@ -269,6 +396,7 @@ class TflPdModel(PdBaseModel):
                     detection_d['joint_x_y_list'].append([x, y])
                     detection_d['joint_z_list'].append(z)
                     detection_d['score_percentages_list'].append(score_percentage)
+                    valid_joints_found += 1
                 else:
                     detection_d['joint_x_y_list'].append(self.NOT_FOUND_PAIR)
                     detection_d['joint_z_list'].append(self.NOT_FOUND_VALUE)
@@ -278,7 +406,18 @@ class TflPdModel(PdBaseModel):
                     d_msg = '{}\tpose {}: {}({}): xy={}, z={}, score=({}%)'
                     print(d_msg.format(tabs * '\t', pose_id, joint_name, joint_id, detection_d['joint_x_y_list'][-1],
                                        detection_d['joint_z_list'][-1], detection_d['score_percentages_list'][-1]))
-            detections.append(detection_d)
+            min_joints_found_ok = valid_joints_found >= self.min_p_valid_joints * len(self.allowed_joint_names)
+            pose_valid = min_joints_found_ok and valid_joints_found >= 2
+            if pose_valid:  # minimum 2 regardless to self.min_p_valid_joints(which could be zero)
+                detection_d['bbox'] = PdBaseModel.get_bbox_dict(detection_d['joint_x_y_list'])
+                if ack:
+                    print('{}\tbbox:{}'.format(tabs * '\t', detection_d['bbox']))
+                detections.append(detection_d)
+            else:
+                if ack:
+                    min_needed = max(self.min_p_valid_joints * len(self.allowed_joint_names), 2)
+                    msg = '{}\tPose {} was dumped. It had valid_joints_found={} (min needed {})'
+                    print(msg.format(tabs * '\t', pose_id, valid_joints_found, min_needed))
         return detections
 
     def detect_cv_img(
@@ -317,10 +456,12 @@ class TflPdModelPoseNet(TflPdModel):
             model_name: str,
             threshold: float = None,
             allowed_joint_names: list = None,
+            min_p_valid_joints: float = 0.3,
             check_type: bool = True
     ):
         super().__init__(save_load_dir=save_load_dir, model_name=model_name, threshold=threshold,
-                         allowed_joint_names=allowed_joint_names, check_type=False)
+                         allowed_joint_names=allowed_joint_names, min_p_valid_joints=min_p_valid_joints,
+                         check_type=False)
         if check_type and not self.model_type_valid(self.model_cfg['model_type'], cfg.ModelType.PdTflPoseNet.value):
             exit(-1)
         return
@@ -446,7 +587,9 @@ class TflPdModelPoseNet(TflPdModel):
                 'joint_ids_list': [],
                 'joint_x_y_list': [],
                 'score_percentages_list': [],
+                'bbox': {}
             }
+            valid_joints_found = 0  # max is len(self.allowed_joint_names)
             for joint_id, joint_name in self.joint_names.items():
                 detection_d['joint_names_list'].append(joint_name)
                 detection_d['joint_ids_list'].append(joint_id)
@@ -464,6 +607,7 @@ class TflPdModelPoseNet(TflPdModel):
                 if self.model_cfg['threshold'] <= score_frac <= 1.0 and joint_name in self.allowed_joint_names:
                     detection_d['joint_x_y_list'].append([x, y])
                     detection_d['score_percentages_list'].append(score_percentage)
+                    valid_joints_found += 1
                 else:
                     detection_d['joint_x_y_list'].append(self.NOT_FOUND_PAIR)
                     detection_d['score_percentages_list'].append(self.NOT_FOUND_VALUE)
@@ -472,17 +616,28 @@ class TflPdModelPoseNet(TflPdModel):
                     d_msg = '{}\tpose {}: {}({}): xy={}, score=({}%)'
                     print(d_msg.format(tabs * '\t', pose_id, joint_name, joint_id, detection_d['joint_x_y_list'][-1],
                                        detection_d['score_percentages_list'][-1]))
-            detections.append(detection_d)
+            min_joints_found_ok = valid_joints_found >= self.min_p_valid_joints * len(self.allowed_joint_names)
+            pose_valid = min_joints_found_ok and valid_joints_found >= 2
+            if pose_valid:  # minimum 2 regardless to self.min_p_valid_joints(which could be zero)
+                detection_d['bbox'] = PdBaseModel.get_bbox_dict(detection_d['joint_x_y_list'])
+                if ack:
+                    print('{}\tbbox:{}'.format(tabs * '\t', detection_d['bbox']))
+                detections.append(detection_d)
+            else:
+                if ack:
+                    min_needed = max(self.min_p_valid_joints * len(self.allowed_joint_names), 2)
+                    msg = '{}\tPose {} was dumped. It had valid_joints_found={} (min needed {})'
+                    print(msg.format(tabs * '\t', pose_id, valid_joints_found, min_needed))
         return detections
 
 
 class Cv2PdModel(PdBaseModel):
-    BAD_P = (-1, -1)
 
     def __init__(self,
                  save_load_dir: str,
                  model_name: str,
                  allowed_joint_names: list = None,
+                 min_p_valid_joints: float = 0.3,
                  threshold: float = None,
                  in_dims: tuple = None,
                  scalefactor: float = None,
@@ -495,6 +650,10 @@ class Cv2PdModel(PdBaseModel):
         """
         :param save_load_dir: where the model is saved (or will be if not exists)
         :param model_name: valid name in MODEL_CONF.keys()
+        :param allowed_joint_names: joint_names to track from the joint_names of the model
+        :param min_p_valid_joints:
+            let x=min_p_valid_joints*len(allowed_joint_names)
+            to keep a pose: we need max(x,2) joints found
         for all the following - if is None: take default value from MODELS_DNN_OBJECT_DETECTION_META_DATA['model_name']
         :param threshold: only detection above this threshold will be returned
         :param in_dims:
@@ -505,7 +664,8 @@ class Cv2PdModel(PdBaseModel):
         example:
         see:
         """
-        super().__init__(save_load_dir=save_load_dir, model_name=model_name, allowed_joint_names=allowed_joint_names)
+        super().__init__(save_load_dir=save_load_dir, model_name=model_name, allowed_joint_names=allowed_joint_names,
+                         min_p_valid_joints=min_p_valid_joints)
         if check_type and not self.model_type_valid(self.model_cfg['model_type'], cfg.ModelType.PdCvNormal.value):
             exit(-1)
         self.pose_net = None
@@ -660,8 +820,9 @@ class Cv2PdModel(PdBaseModel):
                 'joint_ids_list': [],
                 'joint_x_y_list': [],
                 'score_percentages_list': [],
+                'bbox': {}
             }
-
+            valid_joints_found = 0  # max is len(self.allowed_joint_names)
             for joint_id, joint_name in self.joint_names.items():
                 detection_d['joint_names_list'].append(joint_name)
                 detection_d['joint_ids_list'].append(joint_id)
@@ -675,6 +836,7 @@ class Cv2PdModel(PdBaseModel):
                 if self.model_cfg['threshold'] <= score_frac <= 1.0 and joint_name in self.allowed_joint_names:
                     detection_d['joint_x_y_list'].append([x, y])
                     detection_d['score_percentages_list'].append(score_percentage)
+                    valid_joints_found += 1
                 else:
                     detection_d['joint_x_y_list'].append(self.NOT_FOUND_PAIR)
                     detection_d['score_percentages_list'].append(self.NOT_FOUND_VALUE)
@@ -683,7 +845,18 @@ class Cv2PdModel(PdBaseModel):
                     d_msg = '{}\tpose {}: {}({}): xy={}, score=({}%)'
                     print(d_msg.format(tabs * '\t', pose_id, joint_name, joint_id, detection_d['joint_x_y_list'][-1],
                                        detection_d['score_percentages_list'][-1]))
-            detections.append(detection_d)
+            min_joints_found_ok = valid_joints_found >= self.min_p_valid_joints * len(self.allowed_joint_names)
+            pose_valid = min_joints_found_ok and valid_joints_found >= 2
+            if pose_valid:  # minimum 2 regardless to self.min_p_valid_joints(which could be zero)
+                detection_d['bbox'] = PdBaseModel.get_bbox_dict(detection_d['joint_x_y_list'])
+                if ack:
+                    print('{}\tbbox:{}'.format(tabs * '\t', detection_d['bbox']))
+                detections.append(detection_d)
+            else:
+                if ack:
+                    min_needed = max(self.min_p_valid_joints * len(self.allowed_joint_names), 2)
+                    msg = '{}\tPose {} was dumped. It had valid_joints_found={} (min needed {})'
+                    print(msg.format(tabs * '\t', pose_id, valid_joints_found, min_needed))
         return detections
 
 
@@ -692,6 +865,7 @@ class Cv2PdModelCocoMultiPoses(Cv2PdModel):
                  save_load_dir: str,
                  model_name: str,
                  allowed_joint_names: list = None,
+                 min_p_valid_joints: float = 0.3,
                  threshold: float = None,
                  in_dims: tuple = None,
                  scalefactor: float = None,
@@ -717,8 +891,8 @@ class Cv2PdModelCocoMultiPoses(Cv2PdModel):
         # inWidth = int((inHeight / frameHeight) * frameWidth)
         super().__init__(
             save_load_dir=save_load_dir, model_name=model_name, allowed_joint_names=allowed_joint_names,
-            threshold=threshold, in_dims=in_dims, scalefactor=scalefactor, mean=mean, swapRB=swapRB, crop=crop,
-            check_type=False, device=device
+            min_p_valid_joints=min_p_valid_joints, threshold=threshold, in_dims=in_dims, scalefactor=scalefactor,
+            mean=mean, swapRB=swapRB, crop=crop, check_type=False, device=device
         )
         if check_type and not self.model_type_valid(self.model_cfg['model_type'], cfg.ModelType.PdCvCocoMulti.value):
             exit(-1)
@@ -991,8 +1165,9 @@ class Cv2PdModelCocoMultiPoses(Cv2PdModel):
                 'joint_ids_list': [],
                 'joint_x_y_list': [],
                 'score_percentages_list': [],
+                'bbox': {}
             }
-
+            valid_joints_found = 0  # max is len(self.allowed_joint_names)
             for joint_id, joint_name in self.joint_names.items():
                 detection_d['joint_names_list'].append(joint_name)
                 detection_d['joint_ids_list'].append(joint_id)
@@ -1007,6 +1182,7 @@ class Cv2PdModelCocoMultiPoses(Cv2PdModel):
                         score_percentage = round(score_frac * 100, fp)
                         detection_d['joint_x_y_list'].append([x, y])
                         detection_d['score_percentages_list'].append(score_percentage)
+                        valid_joints_found += 1
                     else:
                         detection_d['joint_x_y_list'].append(self.NOT_FOUND_PAIR)
                         detection_d['score_percentages_list'].append(self.NOT_FOUND_VALUE)
@@ -1017,5 +1193,17 @@ class Cv2PdModelCocoMultiPoses(Cv2PdModel):
                     d_msg = '{}\t\tpose {}: {}({}): xy={}, score=({}%)'
                     print(d_msg.format(tabs * '\t', i, joint_name, joint_id, detection_d['joint_x_y_list'][-1],
                                        detection_d['score_percentages_list'][-1]))
-            detections.append(detection_d)
+
+            min_joints_found_ok = valid_joints_found >= self.min_p_valid_joints * len(self.allowed_joint_names)
+            pose_valid = min_joints_found_ok and valid_joints_found >= 2
+            if pose_valid:  # minimum 2 regardless to self.min_p_valid_joints(which could be zero)
+                detection_d['bbox'] = PdBaseModel.get_bbox_dict(detection_d['joint_x_y_list'])
+                if ack:
+                    print('{}\tbbox:{}'.format(tabs * '\t', detection_d['bbox']))
+                detections.append(detection_d)
+            else:
+                if ack:
+                    min_needed = max(self.min_p_valid_joints * len(self.allowed_joint_names), 2)
+                    msg = '{}\tPose {} was dumped. It had valid_joints_found={} (min needed {})'
+                    print(msg.format(tabs * '\t', i, valid_joints_found, min_needed))
         return detections
