@@ -1,9 +1,15 @@
 from wizzi_utils.pyplot import pyplot_tools as pyplt
 from wizzi_utils.misc import misc_tools as mt
+from wizzi_utils.misc.test import test_misc_tools as mtt
+from wizzi_utils.open_cv import open_cv_tools as cvt
+from wizzi_utils.open_cv.test import test_open_cv_tools as cvtt
 import numpy as np
+from mpl_toolkits.mplot3d import Axes3D
 # noinspection PyPackageRequirements
 import matplotlib.pyplot as plt
-from mpl_toolkits.mplot3d import Axes3D
+
+SLEEP = 0.2  # sleep between iterations
+PLT_MAX_TIME = 2  # close plt after x seconds - minimum 2
 
 
 def get_colors_formats_test():
@@ -62,12 +68,18 @@ def RGB_to_RGBA_and_BGR_test():
     return
 
 
+def colors_plot_test():
+    mt.get_function_name(ack=True, tabs=0)
+    pyplt.colors_plot(ack=True, tabs=0, max_time=PLT_MAX_TIME)
+    return
+
+
 def get_ticks_list_test():
     mt.get_function_name(ack=True, tabs=0)
     ticks_list = pyplt.get_ticks_list(x_low=10, x_high=30, p=0.1)
-    print(mt.to_str(ticks_list, '\tticks_list', data_chars=0))
+    print(mt.to_str(ticks_list, '\tticks_list', chars=0))
     ticks_list = pyplt.get_ticks_list(x_low=0, x_high=500, p=0.2)
-    print(mt.to_str(ticks_list, '\tticks_list', data_chars=0))
+    print(mt.to_str(ticks_list, '\tticks_list', chars=0))
     return
 
 
@@ -92,6 +104,7 @@ def move_figure_x_y_test():
     options = [(0, 0), (100, 0), (0, 100), (150, 150), (400, 400), (250, 350)]
     print('\tVisual test: move to all options {}'.format(options))
     print('\t\tClick Esc to close all')
+    timers = []
     for x_y in options:
         title = 'move to {}'.format(x_y)
         fig, ax = plt.subplots()
@@ -99,9 +112,13 @@ def move_figure_x_y_test():
         pyplt.set_figure_title(fig, title='move_figure_x_y_test()')
         pyplt.set_axes_title(ax, title)
         fig.canvas.mpl_connect('key_press_event', pyplt.on_click_close_all)
-        ax.plot(t, s)
+        ax.plot(t, s, c=pyplt.get_random_color('str'))
         pyplt.move_figure_x_y(fig, x_y=x_y)
+        timer = pyplt.add_timer(fig, PLT_MAX_TIME)
+        timers.append(timer)
     plt.show(block=True)
+    for timer in timers:
+        timer.stop()
     return
 
 
@@ -109,19 +126,57 @@ def move_figure_by_str_test():
     mt.get_function_name(ack=True, tabs=0)
     t = np.arange(0.0, 2.0, 0.01)
     s = 1 + np.sin(2 * np.pi * t)
-    options = ['top_right', 'top_center', 'top_left', 'bottom_right', 'bottom_center', 'bottom_left']
+    options = pyplt.Location.get_location_list_by_rows()
     print('\tVisual test: move to all options {}'.format(options))
     print('\t\tClick Esc to close all')
+    timers = []
     for where_to in options:
         title = 'move to {}'.format(where_to)
-        fig, ax = plt.subplots()
-        pyplt.set_window_title(fig, title='move_figure_by_str_test()')
-        pyplt.set_figure_title(fig, title='move_figure_by_str_test()')
+        resize = 0.7
+        figsize = (6.4 * resize, 4.8 * resize)
+        fig, ax = plt.subplots(figsize=figsize)
+        pyplt.set_window_title(fig, title=title)
+        pyplt.set_figure_title(fig, title=title)
         pyplt.set_axes_title(ax, title)
         fig.canvas.mpl_connect('key_press_event', pyplt.on_click_close_all)
-        ax.plot(t, s)
+        ax.plot(t, s, c=pyplt.get_random_color('str'))
         pyplt.move_figure_by_str(fig, where=where_to)
+        timer = pyplt.add_timer(fig, PLT_MAX_TIME)
+        timers.append(timer)
     plt.show(block=True)
+    for timer in timers:
+        timer.stop()
+    return
+
+
+def add_update_2d_scatter_test():
+    mt.get_function_name(ack=True, tabs=0)
+    fig, axes = plt.subplots()
+    pyplt.set_window_title(fig, 'add_update_2d_scatter_test()')
+    # create the fig world on 0 to 4 square
+    data = [[0, 0], [4, 4]]  # nx2 base data. if you want a dashboard: data = [0, 0] - just set fig lims
+    # c = 'g'  # equivalent: ['g'], pyplt.get_RGBA_color('g'), [pyplt.get_RGBA_color('g')]
+    c = ['g', 'r']  # equivalent: [pyplt.get_RGBA_color('g'), 'r']
+    sc = pyplt.add_2d_scatter(ax=axes, data=data, c=c, marker='o', marker_s=100, label='sc')
+    pyplt.render_plot(fig=fig, block=False)
+
+    mt.sleep(seconds=SLEEP)
+    new_data = np.array([[2, 2], [3, 3]])  # notice data has to be in the fig world
+    # colors = [pyplt.get_RGBA_color('y')]  # list of size 1 or n of RGBA colors
+    # colors = pyplt.get_random_RBGA_color_map(n=2)
+    colors = [pyplt.get_random_color('RGBA'), pyplt.get_RGBA_color('b')]  # list of size 1 or n of RGBA colors
+    pyplt.update_2d_scatter(sc=sc, sc_dict={'data': new_data, 'c': colors})
+    pyplt.render_plot(fig=fig, block=False)
+
+    mt.sleep(seconds=SLEEP)
+    new_data = np.array([[1, 2.33], [3.4, 4.4]])  # notice data has to be in the fig world
+    pyplt.update_2d_scatter(sc=sc, sc_dict={'data': new_data})  # no colors
+    pyplt.render_plot(fig=fig, block=False)
+
+    mt.sleep(seconds=SLEEP)
+    pyplt.update_2d_scatter(sc=sc, sc_dict={'data': []})  # no colors
+
+    pyplt.finalize_plot(fig, PLT_MAX_TIME)
     return
 
 
@@ -145,7 +200,7 @@ def plot_2d_one_figure_iterative_test():
             },
             {
                 'data': mt.np_random_integers(low=0, high=480, size=(10, 2)),
-                'c': 'g',
+                'c': pyplt.get_random_color('str'),
                 'label': 'plot0_data1',
                 'marker': 'o',
                 'marker_s': 100,
@@ -162,14 +217,14 @@ def plot_2d_one_figure_iterative_test():
         data_plot_i=data_plot_0,
         win_d={
             'title': 'plot_2d_one_figure_iterative_test()',
-            'location': 'bottom_center',
+            'location': pyplt.Location.CENTER_CENTER.value,
             'resize': 1.2,
             'zoomed': False,
         },
     )
 
     for i in range(iters):
-        mt.sleep(seconds=1)
+        mt.sleep(seconds=SLEEP)
 
         # emulate data of each scatter
         points_per_sc = 20
@@ -202,10 +257,12 @@ def plot_2d_one_figure_iterative_test():
 
         # second option if you have more stuff to render
         # pyplt.render_plot(fig, block=block)
-    save_path = 'plot_2d_iterative_plots'
+
+    mt.create_dir(mtt.TEMP_FOLDER1)
+    save_path = '{}/{}'.format(mtt.TEMP_FOLDER1, mtt.JUST_A_NAME)
     pyplt.save_plot(path=save_path, ack=True, tabs=2)
-    pyplt.finalize_plot(fig)
-    mt.delete_file(file='{}.png'.format(save_path), tabs=2)
+    pyplt.finalize_plot(fig, PLT_MAX_TIME)
+    mt.delete_dir_with_files(mtt.TEMP_FOLDER1)
     return
 
 
@@ -230,7 +287,7 @@ def plot_2d_many_figures_iterative_test():
             },
             {
                 'data': mt.np_random_integers(low=0, high=480, size=(10, 2)),
-                'c': 'g',
+                'c': pyplt.get_random_color('str'),
                 'label': 'plot0_data1',
                 'marker': pyplt.get_random_marker(),
                 'marker_s': 100,
@@ -291,14 +348,14 @@ def plot_2d_many_figures_iterative_test():
         data_all_plots=[data_plot_0, data_plot_1, data_plot_2, data_plot_3],
         win_d={
             'title': 'plot_2d_many_figures_iterative_test()',
-            'location': 'top_center',
+            'location': pyplt.Location.TOP_CENTER.value,
             'resize': 1.5,
             'zoomed': False,
         },
     )
 
     for i in range(iters):
-        mt.sleep(seconds=1)
+        mt.sleep(seconds=SLEEP)
 
         # emulate data of each scatter
         points_per_sc = 20
@@ -333,10 +390,11 @@ def plot_2d_many_figures_iterative_test():
 
         # second option if you have more stuff to render
         # pyplt.render_plot(fig, block=block)
-    save_path = 'plot_2d_iterative_plots'
+    mt.create_dir(mtt.TEMP_FOLDER1)
+    save_path = '{}/{}'.format(mtt.TEMP_FOLDER1, mtt.JUST_A_NAME)
     pyplt.save_plot(path=save_path, ack=True, tabs=2)
-    pyplt.finalize_plot(fig)
-    mt.delete_file(file='{}.png'.format(save_path), tabs=2)
+    pyplt.finalize_plot(fig, PLT_MAX_TIME)
+    mt.delete_dir_with_files(mtt.TEMP_FOLDER1)
     return
 
 
@@ -345,7 +403,7 @@ def plot_2d_one_figure_test():
     datum = [
         {
             'data': mt.np_random_integers(low=0, high=480, size=(20, 2)),
-            'c': 'r',
+            'c': pyplt.get_random_color('str'),
             'label': 'plot0_data0',
             'marker': 'x',
         },
@@ -361,7 +419,8 @@ def plot_2d_one_figure_test():
     pyplt.plot_2d_one_figure(
         datum=datum,
         fig_title='plot_2d_one_figure_test()',
-        win_d=pyplt.WINDOW_DEFAULT
+        win_d=pyplt.WINDOW_DEFAULT,
+        max_time=PLT_MAX_TIME
     )
     return
 
@@ -391,7 +450,8 @@ def plot_2d_many_figures_test():
         datum_list=datum_list,
         sub_titles=['t1', 't2'],
         fig_title='plot_2d_many_figures_test()',
-        win_d=pyplt.WINDOW_DEFAULT
+        win_d=pyplt.WINDOW_DEFAULT,
+        max_time=PLT_MAX_TIME
     )
     return
 
@@ -408,7 +468,7 @@ def plot_2d_iterative_dashboard_test():
         'yticks': None,
         'datum': [
             {
-                'c': 'r',
+                'c': pyplt.get_RGBA_color('r'),
                 'label': 'plot0_data0',
                 'marker': pyplt.get_random_marker(),
                 'marker_s': 125,
@@ -430,7 +490,7 @@ def plot_2d_iterative_dashboard_test():
         data_plot_i=data_plot_0,
         win_d={
             'title': 'plot_2d_iterative_dashboard_test()',
-            'location': 'bottom_center',
+            'location': pyplt.Location.BOTTOM_CENTER.value,
             'resize': 1.2,
             'zoomed': False,
         },
@@ -438,7 +498,7 @@ def plot_2d_iterative_dashboard_test():
     )
 
     for i in range(iters):
-        mt.sleep(seconds=1)
+        mt.sleep(seconds=SLEEP)
 
         # emulate data of each scatter
         points_per_sc = 20
@@ -450,8 +510,8 @@ def plot_2d_iterative_dashboard_test():
                 # 'data': [],  # no refresh
                 'data': mt.np_random_integers(low=0, high=480, size=(points_per_sc, 2)),
                 # 'c': None,  # color doesn't have to change
-                # 'c': [pyplt.get_RGBA_color('g')]  # color could be a list of a color
-                'c': pyplt.get_random_RBGA_color_map(points_per_sc)  # color could be a list of n color
+                # 'c': [pyplt.get_RGBA_color('g')]  # color could be a list of a RGBA color
+                # 'c': pyplt.get_random_RBGA_color_map(points_per_sc),  # color could be a list of n RGBA color
             }
             new_data_plot_i.append(new_data_i)
 
@@ -468,10 +528,11 @@ def plot_2d_iterative_dashboard_test():
 
         # second option if you have more stuff to render
         # pyplt.render_plot(fig, block=block)
-    save_path = 'plot_2d_iterative_plots'
+    mt.create_dir(mtt.TEMP_FOLDER1)
+    save_path = '{}/{}'.format(mtt.TEMP_FOLDER1, mtt.JUST_A_NAME)
     pyplt.save_plot(path=save_path, ack=True, tabs=2)
-    pyplt.finalize_plot(fig)
-    mt.delete_file(file='{}.png'.format(save_path), tabs=2)
+    pyplt.finalize_plot(fig, PLT_MAX_TIME)
+    mt.delete_dir_with_files(mtt.TEMP_FOLDER1)
     return
 
 
@@ -519,7 +580,7 @@ def plot_2d_iterative_dashboards_test():
         data_all_plots=[data_plot_0, data_plot_1],
         win_d={
             'title': 'plot_2d_iterative_dashboards_test()',
-            'location': 'top_center',
+            'location': pyplt.Location.TOP_CENTER.value,
             'resize': 1.5,
             'zoomed': False,
         },
@@ -527,7 +588,7 @@ def plot_2d_iterative_dashboards_test():
     )
 
     for i in range(iters):
-        mt.sleep(seconds=1)
+        mt.sleep(seconds=SLEEP)
 
         # emulate data of each scatter
         points_per_sc = 20
@@ -559,10 +620,11 @@ def plot_2d_iterative_dashboards_test():
 
         # second option if you have more stuff to render
         # pyplt.render_plot(fig, block=block)
-    save_path = 'plot_2d_iterative_plots'
+    mt.create_dir(mtt.TEMP_FOLDER1)
+    save_path = '{}/{}'.format(mtt.TEMP_FOLDER1, mtt.JUST_A_NAME)
     pyplt.save_plot(path=save_path, ack=True, tabs=2)
-    pyplt.finalize_plot(fig)
-    mt.delete_file(file='{}.png'.format(save_path), tabs=2)
+    pyplt.finalize_plot(fig, PLT_MAX_TIME)
+    mt.delete_dir_with_files(mtt.TEMP_FOLDER1)
     return
 
 
@@ -576,7 +638,7 @@ def plot_x_y_std_test():
 
     U_errors = [10, 8, 3]
     U_errors_vars = [4, 3, 1.5]
-    group_u = (U_errors, U_errors_vars, 'r', 'U')
+    group_u = (U_errors, U_errors_vars, pyplt.get_random_color(), 'U')
 
     print('\tVisual test: errors and stds')
     pyplt.plot_x_y_std(
@@ -588,20 +650,22 @@ def plot_x_y_std_test():
         y_label='Y',
         save_path=None,
         show_plot=True,
-        with_shift=True
+        with_shift=True,
+        max_time=PLT_MAX_TIME
     )
     return
 
 
 def histogram_test():
     mt.get_function_name(ack=True, tabs=0)
-    data = mt.np_uniform(shape=1000, lows=0, highs=10000)
+    data = mt.np_uniform(shape=(1000,), lows=0, highs=10000)
     print('\tVisual test: histogram')
     pyplt.histogram(
         values=data,
         title='histogram: 10 bins of 1000 numbers from 0 to 10000',
         save_path=None,
         bins_n=10,
+        max_time=PLT_MAX_TIME
     )
     return
 
@@ -609,61 +673,132 @@ def histogram_test():
 def compare_images_sets_test():
     mt.get_function_name(ack=True, tabs=0)
     try:
-        # noinspection PyPackageRequirements
-        from torchvision import datasets
-        # choose data set - both work
-        # data_root = path to the data else download
         print('\tVisual test: 2 compare_images_sets')
-        data_root = './Datasets/'
         title = 'compare_images_sets_test()'
-        mt.create_dir(data_root, ack=True)  # TODO - delete folder?
-        # dataset = datasets.MNIST(root=data_root, train=False, download=True)
-        dataset = datasets.CIFAR10(root=data_root, train=False, download=True)
-        set_a = dataset.data[:3]
-        set_b = dataset.data[10:50]
-        pyplt.compare_images_sets(set_a, set_b, title=title)
-        set_a = dataset.data[0:3]
-        set_b = dataset.data[0:3]
-        pyplt.compare_images_sets(set_a, set_b, title=title)
+        imgBGR = cvtt.load_img_from_web(mtt.SO_LOGO)
+        imgRGB = cvt.BGR_img_to_RGB(imgBGR)
+        img_gray = cvt.BGR_img_to_gray(imgBGR)
+        img_gray = cvt.gray_scale_img_to_BGR_form(img_gray)
+        # print(mt.to_str(imgBGR))
+        # print(mt.to_str(imgRGB))
+        # print(mt.to_str(img_gray))
+        img_set_a = np.array([imgRGB, imgRGB, imgRGB], dtype=np.uint8)
+        img_set_b = np.array([imgRGB, imgBGR, img_gray], dtype=np.uint8)
+        # print(mt.to_str(img_set_a))
+        # print(mt.to_str(img_set_b))
+        pyplt.compare_images_sets(img_set_a, img_set_b, title=title, max_time=PLT_MAX_TIME)
     except ModuleNotFoundError as e:
-        mt.exception_error(e)
+        mt.exception_error(e, real_exception=True)
     return
 
 
 def compare_images_multi_sets_squeezed_test():
     mt.get_function_name(ack=True, tabs=0)
     try:
-        # noinspection PyPackageRequirements
-        import torch
-        # noinspection PyPackageRequirements
-        from torchvision import datasets
-        # noinspection PyPackageRequirements
-        import torchvision.transforms as transforms
+        # # OLD CODE
+        # import torch
+        # from torchvision import datasets
+        # import torchvision.transforms as transforms
+        # transform = transforms.Compose([transforms.ToTensor(), ])
+        # # choose data set - both work
+        # # data_root = path to the data else download
+        # print('\tVisual test: 2 compare_images_multi_sets_squeezed')
+        # data_root = './Datasets/'
+        # mt.create_dir(data_root, ack=True)
+        # # dataset = datasets.MNIST(root=data_root, train=False, download=False, transform=transform)
+        # dataset = datasets.CIFAR10(root=data_root, train=False, download=False, transform=transform)
+        # # noinspection PyUnresolvedReferences
+        # data_loader = torch.utils.data.DataLoader(dataset, batch_size=32, shuffle=True, num_workers=2)
+        # # noinspection PyUnresolvedReferences
+        # images32, labels = iter(data_loader).next()
+        #
+        # images = images32[:16]  # imagine the first 16 are base images and predicted_images are the model output
+        # predicted_images = images32[16:32]
+        # print(images.shape)
+        # print(predicted_images.shape)
+        # d = {'original_data': images, 'predicted_data': predicted_images}
+        # pyplt.compare_images_multi_sets_squeezed(
+        #     sets_dict=d,
+        #     title='comp',
+        #     desc=True,
+        #     tabs=1
+        # )
 
-        transform = transforms.Compose([transforms.ToTensor(), ])
-        # choose data set - both work
-        # data_root = path to the data else download
         print('\tVisual test: 2 compare_images_multi_sets_squeezed')
-        data_root = './Datasets/'
-        mt.create_dir(data_root, ack=True)  # TODO - delete folder?
-        # dataset = datasets.MNIST(root=data_root, train=False, download=False, transform=transform)
-        dataset = datasets.CIFAR10(root=data_root, train=False, download=False, transform=transform)
-        # noinspection PyUnresolvedReferences
-        data_loader = torch.utils.data.DataLoader(dataset, batch_size=32, shuffle=True, num_workers=2)
-        # noinspection PyUnresolvedReferences
-        images32, labels = iter(data_loader).next()
+        title = 'compare_images_multi_sets_squeezed_test()'
+        imgBGR = cvtt.load_img_from_web(mtt.SO_LOGO)
+        imgRGB = cvt.BGR_img_to_RGB(imgBGR)
+        img_gray = cvt.BGR_img_to_gray(imgBGR)
+        img_gray = cvt.gray_scale_img_to_BGR_form(img_gray)
+        # print(mt.to_str(imgBGR))
+        # print(mt.to_str(imgRGB))
+        # print(mt.to_str(img_gray))
 
-        images = images32[:16]  # imagine the first 16 are base images and predicted_images are the model output
-        predicted_images = images32[16:32]
-        d = {'original_data': images, 'predicted_data': predicted_images}
+        # from (height,width,3) -> (3,height,width)
+        imgBGR = np.swapaxes(imgBGR, 1, 2)
+        imgBGR = np.swapaxes(imgBGR, 0, 1)
+        imgRGB = np.swapaxes(imgRGB, 1, 2)
+        imgRGB = np.swapaxes(imgRGB, 0, 1)
+        img_gray = np.swapaxes(img_gray, 1, 2)
+        img_gray = np.swapaxes(img_gray, 0, 1)
+        # print(mt.to_str(imgBGR))
+        # print(mt.to_str(imgRGB))
+        # print(mt.to_str(img_gray))
+
+        # need to normalize by div max color
+        img_set_a = np.array([imgRGB, imgRGB, imgRGB], dtype=np.float) / 255
+        img_set_b = np.array([imgRGB, imgBGR, img_gray], dtype=np.float) / 255
+        # print(mt.to_str(img_set_a))
+        # print(mt.to_str(img_set_b))
+
+        d = {
+            'original_data': img_set_a,
+            'predicted_data': img_set_b,
+            'for_fun': img_set_b,
+            'for_fun2': img_set_b
+        }
         pyplt.compare_images_multi_sets_squeezed(
             sets_dict=d,
-            title='comp',
-            desc=True,
-            tabs=1
+            title=title,
+            ack=True,
+            tabs=1,
+            max_time=PLT_MAX_TIME
         )
+
     except ModuleNotFoundError as e:
-        mt.exception_error(e)
+        mt.exception_error(e, real_exception=True)
+    return
+
+
+def add_update_3d_scatter_test():
+    mt.get_function_name(ack=True, tabs=0)
+    fig = plt.figure()
+    axes = Axes3D(fig)
+    pyplt.set_window_title(fig, 'add_update_2d_scatter_test()')
+    # create the fig world on 0 to 5 cube
+    # nx3 base data. if you want a dashboard: data = [0, 0,0] - just set fig lims
+    data = [[0, 0, 0], [4, 4, 4], [5, 5, 5]]
+    # c = 'g'  # equivalent: ['g'], pyplt.get_RGBA_color('g'), [pyplt.get_RGBA_color('g')]
+    c = ['g', 'r', 'b']  # equivalent: [pyplt.get_RGBA_color('g'), 'r', 'b]
+    sc = pyplt.add_3d_scatter(ax=axes, data=data, c=c, marker='o', marker_s=100, label='sc')
+    pyplt.render_plot(fig=fig, block=False)
+
+    mt.sleep(seconds=SLEEP)
+    new_data = np.array([[2, 2, 2], [3, 3, 3]])  # notice data has to be in the fig world
+    # colors = 'y' # equivalent pyplt.get_RGBA_color('y'), [pyplt.get_RGBA_color('y')]
+    colors = ['y', pyplt.get_RGBA_color('b')]  # list of size n of RGBA or str colors
+    pyplt.update_3d_scatter(sc=sc, sc_dict={'data': new_data, 'c': colors})
+    pyplt.render_plot(fig=fig, block=False)
+
+    mt.sleep(seconds=SLEEP)
+    new_data = np.array([[1, 2.33, 2.1], [3.4, 4.4, 3.1]])  # notice data has to be in the fig world
+    pyplt.update_3d_scatter(sc=sc, sc_dict={'data': new_data})  # no colors
+    pyplt.render_plot(fig=fig, block=False)
+
+    mt.sleep(seconds=SLEEP)
+    pyplt.update_3d_scatter(sc=sc, sc_dict={'data': []})  # no colors
+
+    pyplt.finalize_plot(fig, PLT_MAX_TIME)
     return
 
 
@@ -684,7 +819,7 @@ def plot_3d_iterative_dashboard_test():
         'zticks': pyplt.get_ticks_list(-20, 20, 0.5),
         'datum': [
             {
-                'c': 'r',
+                'c': pyplt.get_RGBA_color('r'),
                 'label': 'plot0_data0',
                 'marker': 'o',
                 'marker_s': 150,
@@ -708,7 +843,7 @@ def plot_3d_iterative_dashboard_test():
         data_plot_i=data_plot_0,
         win_d={
             'title': 'plot_3d_iterative_dashboard_test()',
-            'location': 'top_center',
+            'location': pyplt.Location.CENTER_CENTER.value,
             'resize': 1.5,
             'zoomed': False,
         },
@@ -730,15 +865,15 @@ def plot_3d_iterative_dashboard_test():
     pyplt.add_cube3d_around_origin(ax, edge_len=4, add_labels=False)
 
     # should call legend if you want custom add ons in it
-    # legend = pyplt.LEGEND_DEFAULT
-    # plt.legend(loc=legend['loc'], ncol=legend['ncol'], fancybox=legend['fancybox'],
-    #            framealpha=legend['framealpha'], edgecolor=legend['edgecolor'])
+    legend = pyplt.LEGEND_DEFAULT
+    plt.legend(loc=legend['loc'], ncol=legend['ncol'], fancybox=legend['fancybox'],
+               framealpha=legend['framealpha'], edgecolor=legend['edgecolor'])
 
-    pyplt.render_plot(fig=fig, block=True)  # not necessary - only if you want to see the plot before first data comes
+    pyplt.render_plot(fig=fig, block=False)  # not necessary - only if you want to see the plot before first data comes
     points_per_sc = 20
 
     for i in range(iters):
-        mt.sleep(seconds=1)
+        mt.sleep(seconds=SLEEP)
 
         # emulate data of each scatter
         new_data_plot_i = []
@@ -748,8 +883,12 @@ def plot_3d_iterative_dashboard_test():
                 # 'data': [],  # no refresh
                 'data': mt.np_random_integers(low=-15, high=15, size=(points_per_sc, 3)),
                 # 'c': None,  # color doesn't have to change
-                # 'c': [pyplt.get_RGBA_color('g')]  # color could be a list of a color
-                'c': pyplt.get_random_RBGA_color_map(points_per_sc)  # color could be a list of n color
+                # 'c': pyplt.get_RGBA_color('r')  # color could be a RGBA color
+                # 'c': [pyplt.get_RGBA_color('g')]  # color could be a list of a RGBA color
+                'c': pyplt.get_random_RBGA_color_map(points_per_sc),  # color could be a list of n RGBA color
+                # 'c': 'r'  # color could be a single str color
+                # 'c': 'red'  #  color could be a single str color
+                # 'c': ['red'] * points_per_sc  # color could be a list of n string colors
             }
             new_data_plot_i.append(new_data_i)
 
@@ -758,7 +897,7 @@ def plot_3d_iterative_dashboard_test():
                 'fig': fig,
                 'scatters': iterative_scatters,
                 'new_title': 'iter {}'.format(i),
-                'render': True,
+                'render': False,
                 'block': False,
             },
             new_data_plot_i=new_data_plot_i,
@@ -768,11 +907,11 @@ def plot_3d_iterative_dashboard_test():
         center_mass_label.set_text(
             center_mass_label_base.format(np.round(np.mean(new_data_plot_i[0]['data'], axis=0), 2)))
         pyplt.render_plot(fig, block=False)  # must render here due to custom add on
-
-    save_path = 'plot_3d_iterative_dashboard_test'
+    mt.create_dir(mtt.TEMP_FOLDER1)
+    save_path = '{}/{}'.format(mtt.TEMP_FOLDER1, mtt.JUST_A_NAME)
     pyplt.save_plot(path=save_path, ack=True, tabs=2)
-    pyplt.finalize_plot(fig)
-    mt.delete_file(file='{}.png'.format(save_path), tabs=2)
+    pyplt.finalize_plot(fig, PLT_MAX_TIME)
+    mt.delete_dir_with_files(mtt.TEMP_FOLDER1)
     return
 
 
@@ -814,11 +953,12 @@ def plot_3d_one_dashboard():
         data_plot_i=data_plot_0,
         win_d={
             'title': 'plot_3d_one_dashboard()',
-            'location': 'top_center',
+            'location': pyplt.Location.CENTER_CENTER.value,
             'resize': 1.5,
             'zoomed': False,
         },
         center_d=pyplt.CENTER_DEFAULT,
+        max_time=PLT_MAX_TIME
     )
 
     return
@@ -853,7 +993,7 @@ def plot_3d_cube_test():
 
     print('\tVisual test: plot_3d_cube_test')
     pyplt.move_figure_by_str(plt.gcf())
-    pyplt.finalize_plot(fig)
+    pyplt.finalize_plot(fig, PLT_MAX_TIME)
     return
 
 
@@ -878,7 +1018,7 @@ def add_cube3d_around_origin_test():
                framealpha=legend['framealpha'], edgecolor=legend['edgecolor'])
 
     print('\tVisual test: add_cube3d_around_origin')
-    pyplt.finalize_plot(fig)
+    pyplt.finalize_plot(fig, PLT_MAX_TIME)
     return
 
 
@@ -889,16 +1029,19 @@ def test_all():
     BGR_to_RGB_and_RGBA_test()
     RGB_to_RGBA_and_BGR_test()
     get_ticks_list_test()
+    colors_plot_test()
     get_random_RGBA_color_map_test()
     screen_dims_test()
     move_figure_x_y_test()
     move_figure_by_str_test()
 
     # iterative plots - 2d and 3d
+    add_update_2d_scatter_test()
     plot_2d_many_figures_iterative_test()
     plot_2d_one_figure_iterative_test()
     plot_2d_iterative_dashboards_test()
     plot_2d_iterative_dashboard_test()
+    add_update_3d_scatter_test()
     plot_3d_iterative_dashboard_test()
 
     # 2d plots
@@ -906,6 +1049,7 @@ def test_all():
     plot_2d_many_figures_test()
     plot_x_y_std_test()
     histogram_test()
+    # 2d comparision
     compare_images_sets_test()
     compare_images_multi_sets_squeezed_test()
 
@@ -913,5 +1057,6 @@ def test_all():
     plot_3d_one_dashboard()
     plot_3d_cube_test()
     add_cube3d_around_origin_test()
+
     print('{}'.format('-' * 20))
     return
