@@ -1,7 +1,9 @@
 from wizzi_utils.socket import socket_tools as st
 from wizzi_utils.misc import misc_tools as mt
+from wizzi_utils.misc.test import test_misc_tools as mtt
 from wizzi_utils.json import json_tools as jt
 import socket
+import os
 import threading
 
 SERVER_ADDRESS = ('localhost', 10000)
@@ -152,18 +154,15 @@ def buffer_to_str_test():
     return
 
 
-def rounds_summary_test():
+def download_file_test():
     mt.get_function_name(ack=True, tabs=0)
-    times_ti = []
-    for t in range(10):
-        print('\tt={}:'.format(t))
-        begin_timer_i = mt.get_timer()
-        # do_work of round t
-        mt.sleep(seconds=0.03)
-        end_timer_i = mt.get_timer()
-        times_ti.append(end_timer_i - begin_timer_i)
-        print('\t\tDONE round={}: total time={}'.format(t, mt.get_timer_delta(begin_timer_i, with_ms=True)))
-    st.rounds_summary(times_ti, tabs=1)
+    mt.create_dir(mtt.TEMP_FOLDER1)
+    dst = '{}/{}.jpg'.format(mtt.TEMP_FOLDER1, mtt.SO_LOGO)
+    st.download_file(url=mtt.IMAGES_D[mtt.SO_LOGO], dst_path=dst)
+    print('\t{} exists ? {}'.format(dst, os.path.exists(dst)))
+
+    # st.download_file(url=mtt.IMAGES_D[mtt.SO_LOGO], dst_path=dst)  # check no overwrite - will fail
+    mt.delete_dir_with_files(dir_path=mtt.TEMP_FOLDER1)
     return
 
 
@@ -173,6 +172,6 @@ def test_all():
     get_host_name_test()
     get_ipv4_test()
     buffer_to_str_test()
-    rounds_summary_test()
+    download_file_test()
     print('{}'.format('-' * 20))
     return
