@@ -1,10 +1,13 @@
 from wizzi_utils.torch import torch_tools as tt
 from wizzi_utils.misc import misc_tools as mt
+from wizzi_utils.misc.test import test_misc_tools as mtt
 import numpy as np
 # noinspection PyPackageRequirements
 import torch
 # noinspection PyPackageRequirements
-from torchvision import datasets
+import torch.nn as nn
+# noinspection PyPackageRequirements
+import torch.nn.functional as F
 
 
 def cuda_on_test():
@@ -91,9 +94,13 @@ def numpy_to_torch_test():
 def to_str_test():
     mt.get_function_name(ack=True, tabs=0)
     t_var = tt.torch_normal(shape=(200, 2, 3, 4), miu=3.5, std=1.2)
-    print(tt.to_str(var=t_var, title='\tt_var', data_chars=25, float_precision=5, recursive=True))
-    np_var = mt.np_normal(shape=(200, 2, 3, 4), mius=3.5, stds=1.2)
-    print(tt.to_str(var=np_var, title='\tnp_var', data_chars=25, float_precision=5, recursive=True))
+    print(tt.to_str(var=t_var, title='\tt_var', chars=25, fp=5, rec=True))
+    t_var = t_var.double()
+    print(tt.to_str(var=t_var, title='\tt_var', chars=25, fp=5, rec=False))
+    print(tt.to_str(var=t_var, title='\tt_var', chars=25, fp=5, wm=False, rec=False))
+    np_var = tt.torch_to_numpy(t_var)
+    print(tt.to_str(var=np_var, title='\tnp_var', chars=25, fp=5, rec=True))
+
     return
 
 
@@ -101,7 +108,8 @@ def save_load_tensor_test():
     mt.get_function_name(ack=True, tabs=0)
     # e.g.saving and loading tensor:
     print('\tExample A(tensor):')
-    path = './a.pt'
+    mt.create_dir(mtt.TEMP_FOLDER1)
+    path = '{}/{}.pt'.format(mtt.TEMP_FOLDER1, mtt.JUST_A_NAME)
     a = torch.ones(size=(2, 3, 29))
     print(tt.to_str(a, '\t\ta'))
     tt.save_tensor(a, path=path, tabs=2)
@@ -111,15 +119,15 @@ def save_load_tensor_test():
 
     # e.g.saving and loading tensors dict:
     print('\tExample B(dict):')
-    path = './b_c.pt'
+    path = '{}/{}.pt'.format(mtt.TEMP_FOLDER1, mtt.JUST_A_NAME)
     b = torch.ones(size=(2, 3, 29))
     c = torch.ones(size=(2, 3, 29))
     b_c = {'b': b, 'c': c}
     print(tt.to_str(b_c, '\t\tb_c'))
     tt.save_tensor(b_c, path=path, tabs=2)
-    b_c2 = tt.load_tensor('./b_c.pt', tabs=2)
-    print(tt.to_str(b_c2, '\t\tb_c2', recursive=True))
-    mt.delete_file(path, tabs=2)
+    b_c2 = tt.load_tensor(path, tabs=2)
+    print(tt.to_str(b_c2, '\t\tb_c2', rec=True))
+    mt.delete_dir_with_files(mtt.TEMP_FOLDER1, tabs=2)
     return
 
 
@@ -274,7 +282,6 @@ def split_tensor_test():
     print(tt.to_str(A, '\tA'))
     print(tt.to_str(A1, '\tA1'))
     print(tt.to_str(A2, '\tA2'))
-
     return
 
 
@@ -287,18 +294,176 @@ def shuffle_tensor_test():
     return
 
 
+def shuffle_tensors_test():
+    mt.get_function_name(ack=True, tabs=0)
+    A = np.array([1, 2, 3, 4, 5, 6])
+    A = tt.numpy_to_torch(A)
+    B = np.array([[1, 1], [2, 2], [3, 3], [4, 4], [5, 5], [6, 6]])
+    print(tt.to_str(A, '\tA'))
+    print(tt.to_str(B, '\tB'))
+    A, B = tt.shuffle_tensors(
+        arr_tuple=(A, B)
+    )
+    print(tt.to_str(A, '\tA'))
+    print(tt.to_str(B, '\tB'))
+    return
+
+
 def count_keys_test():
     mt.get_function_name(ack=True, tabs=0)
-    # data_root = path to the data else download
-    # dataset = datasets.MNIST(root='./Datasets', train=False, download=True)
-    dataset = datasets.CIFAR10(root='./Datasets', train=False, download=True)
-    tt.count_keys(dataset.targets, tabs=1)
+    data_root = mtt.DATASETS
+    mt.create_dir(data_root, ack=True)
+    ds = tt.get_data_set('cifar10', data_root, is_train=False, download=True)
+    tt.count_keys(ds.targets, tabs=1)
+    ds = tt.get_data_set('mnist', data_root, is_train=False, download=True)
+    tt.count_keys(ds.targets, tabs=1)
     return
 
 
 def get_torch_version_test():
     mt.get_function_name(ack=True, tabs=0)
-    print('\t{}'.format(tt.get_torch_version()))
+    tt.get_torch_version(ack=True, tabs=1)
+    return
+
+
+class Mnist_example(nn.Module):
+    # noinspection PyTypeChecker
+    def __init__(self):
+        super(Mnist_example, self).__init__()
+        self.conv1 = nn.Conv2d(1, 32, 3, 1)
+        self.conv2 = nn.Conv2d(32, 64, 3, 1)
+        self.dropout1 = nn.Dropout(0.25)
+        self.dropout2 = nn.Dropout(0.5)
+        self.fc1 = nn.Linear(9216, 128)
+        self.fc2 = nn.Linear(128, 10)
+
+    def forward(self, x):
+        x = self.conv1(x)
+        x = F.relu(x)
+        x = self.conv2(x)
+        x = F.relu(x)
+        x = F.max_pool2d(x, 2)
+        x = self.dropout1(x)
+        x = torch.flatten(x, 1)
+        x = self.fc1(x)
+        x = F.relu(x)
+        x = self.dropout2(x)
+        x = self.fc2(x)
+        output = F.log_softmax(x, dim=1)
+        return output
+
+
+def save_load_model_test():
+    mt.get_function_name(ack=True, tabs=0)
+    net1 = Mnist_example()
+    tt.layer_info(net1, layer='conv1', title='net1 conv1 values', wv=True, tabs=1)
+    mt.create_dir(mtt.TEMP_FOLDER1)
+    path = '{}/{}.pt'.format(mtt.TEMP_FOLDER1, mtt.JUST_A_NAME)
+    tt.save_model(net1, path=path)
+
+    net2 = Mnist_example()
+    if tt.cuda_on():
+        net2 = net2.cuda()
+
+    tt.layer_info(net2, layer='conv1', title='net2 conv1 values', wv=True, tabs=1)
+    tt.load_model(net2, path)
+    tt.layer_info(net2, layer='conv1', title='net2 conv1 values(after load)', wv=True, tabs=1)
+    mt.delete_dir_with_files(mtt.TEMP_FOLDER1, tabs=2)
+    return
+
+
+def model_info_test():
+    mt.get_function_name(ack=True, tabs=0)
+    net1 = Mnist_example()
+    tt.model_info(net1, 'Mnist model', wv=True, tabs=1)
+    return
+
+
+def layer_info_test():
+    mt.get_function_name(ack=True, tabs=0)
+    net1 = Mnist_example()
+    tt.layer_info(net1, layer='conv2', wv=True, tabs=1)
+    return
+
+
+def model_summary_test():
+    mt.get_function_name(ack=True, tabs=0)
+    net1 = Mnist_example().float()  # if cuda_on(): model_summary need float variables
+    tt.model_summary(net1, input_size=(1, 28, 28), batch_size=256)
+    return
+
+
+def model_params_count_test():
+    mt.get_function_name(ack=True, tabs=0)
+    net1 = Mnist_example()
+    print('\ttotal params {:,}'.format(tt.model_params_count(net1)))
+    return
+
+
+def model_status_str_test():
+    mt.get_function_name(ack=True, tabs=0)
+    net1 = Mnist_example()
+    print('\tstatus = {}'.format(tt.model_status_str(net1)))
+    return
+
+
+def set_model_status_test():
+    mt.get_function_name(ack=True, tabs=0)
+    net1 = Mnist_example()
+    print('\tstatus = {}'.format(tt.model_status_str(net1)))
+    tt.set_model_status(net1, status=False)
+    print('\tstatus = {}'.format(tt.model_status_str(net1)))
+    tt.set_model_status(net1, status=True)
+    print('\tstatus = {}'.format(tt.model_status_str(net1)))
+    return
+
+
+def set_layer_status_test():
+    mt.get_function_name(ack=True, tabs=0)
+    net1 = Mnist_example()
+    tt.layer_info(net1, layer='conv2', title='net2')
+    tt.set_layer_status(net1, layers=['conv2'], status=False)
+    tt.model_info(net1, title='net2(post freezing conv2)')
+    return
+
+
+def model_clone_test():
+    mt.get_function_name(ack=True, tabs=0)
+    net1 = Mnist_example()
+    print('\tnet1 address {}'.format(hex(id(net1))))
+    net2 = tt.model_clone(net1)
+    print('\tnet2 address {}'.format(hex(id(net2))))
+    return
+
+
+def model_copy_layers_test():
+    mt.get_function_name(ack=True, tabs=0)
+    net1 = Mnist_example()
+    net2 = Mnist_example()
+    tt.model_info(net1, title='net1', wv=True, tabs=1)
+    tt.model_info(net2, title='net2', wv=True, tabs=1)
+    tt.model_copy_layers(net1, net2, layers=['conv1'])
+    tt.model_info(net2, title='net2(after copy conv1)', wv=True, tabs=1)
+    return
+
+
+def model_copy_except_layers_test():
+    mt.get_function_name(ack=True, tabs=0)
+    net1 = Mnist_example()
+    net2 = Mnist_example()
+    tt.model_info(net1, title='net1', wv=True, tabs=1)
+    tt.model_info(net2, title='net2', wv=True, tabs=1)
+    tt.model_copy_except_layers(net1, net2, layers=['conv1'])
+    tt.model_info(net2, title='net2(after copy all net1 except conv1)', wv=True, tabs=1)
+    return
+
+
+def size_s_ds_test():
+    mt.get_function_name(ack=True, tabs=0)
+    data_root = mtt.DATASETS
+    mt.create_dir(data_root, ack=True)
+    tt.get_data_set('cifar10', data_root, is_train=False, download=True)
+    tt.get_data_set('mnist', data_root, is_train=False, download=True)
     return
 
 
@@ -328,7 +493,20 @@ def test_all():
     de_augment_torch_test()
     split_tensor_test()
     shuffle_tensor_test()
+    shuffle_tensors_test()
     count_keys_test()
     get_torch_version_test()
+    save_load_model_test()
+    model_info_test()
+    layer_info_test()
+    model_summary_test()
+    model_params_count_test()
+    model_status_str_test()
+    set_model_status_test()
+    set_layer_status_test()
+    model_clone_test()
+    model_copy_layers_test()
+    model_copy_except_layers_test()
+    size_s_ds_test()
     print('{}'.format('-' * 20))
     return
